/***********************
** METADATA
***********************/

/****
Created by: George Borjas and Joan Monras 
Date: December 2016
Purpose: Read European Census Data

Inputs: Europe_raw_Census.dta

Outputs: Graphs and regressions on the Balkan episode

****/


/***********************
** COMPUTING RESOURCES
***********************/

clear all
set more off
cd ~
if (regexm("`c(pwd)'","/home/joan")==1) {
 global dropbox "/home/joan/Dropbox/Sciences Po/refugees_and_labor_market_borjas_monras" //Joan's Ubuntu laptop
}		

/***********************
** PROGRAMS
***********************/

cap program drop sumstats_dependent //This program aggregates the data to the appropriate cell
program define sumstats_dependent

tempfile t1 t2

syntax using/,  [agemin(integer 1) agemax(integer 1)  sex(string) age(string) ]  

use "`using'", clear

keep if country==40

drop if year==1996 //Middle of the decade not used
drop if country==250 //France doesn't distinguish foreign origin
drop if country==826 //UK has different education codes (it won't matter because there are very few refugees in the data. 

** age selection

keep if age>=`agemin' & age<=`agemax'

** Drop females if sex==1

if ("`sex'"=="1") {
drop if sex==2
}



*DROP IF ACTIVITY IS NIU
drop if empstat==0
*DROPS IF IN SCHOOL OR RETIRED
drop if empstatd==330 | empstatd==343


** Drop observations without occupation or industry information if occupation or industry cells
if ("`geo'"=="occisco") {
drop if occisco>=10
drop if country==756 //Switzerland does not record the occupation of the unemployed
}
if ("`geo'"=="indgen") {
drop if indgen==0
}
if ("`geo'"=="occisco country") {
drop if occisco>=10
drop if country==756 //Switzerland does not record the occupation of the unemployed
}

** TWO VARIABLES TO IDENTIFY countries:

** Country of birth variable: IE (372) PT (620) RO (642) UK (826)
gen balkan=((bplcountry>=43140 & bplcountry<=43144)|(bplcountry==43030)|(bplcountry==43040)|(bplcountry==43110)| (bplcountry==43130)) ///
          //&(country==372|country==620|country==642|country==826) // Maybe worth leaving Slovenia and Macedonia out: (bplcountry==43110)| (bplcountry==43130)
** Nation variable: AT CH GR SP
replace balkan=1 if ((nation>=43140 & nation <=43144) | (nation==43030)|(nation==43040)|(nation==43110)| (nation==43130)) ///
		    //&(country==040|country==756|country==300|country==724) // Slovenia Macedonia: (nation==43110)| (nation==43130)

gen yugoslavia=((bplcountry>=43140 & bplcountry<=43144)&(country==372|country==620|country==642|country==826))|((nation>=43140 & nation <=43144)&(country==040|country==756|country==300|country==724))
gen bosnia=((bplcountry==43030)&(country==372|country==620|country==642|country==826))|((nation==43030)&(country==040|country==756|country==300|country==724))
gen croatia=((bplcountry==43040)&(country==372|country==620|country==642|country==826))|((nation==43040)&(country==040|country==756|country==300|country==724)) 

generate native=(balkan!=1)

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat==3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

replace balkan=balkan*perwt
replace yugoslavia=yugoslavia*perwt
replace bosnia=bosnia*perwt
replace croatia=croatia*perwt
replace native=native*perwt 
//generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)
generate byte agecode=1*(age>=25 & age<=44) + 2*(age>=45 & age<=59)

gen obs=1

gen time=0 if year <= 1995 
replace time=1 if year > 1995 

replace edattain=2 if edattain==1 //Some countries don't have lower level, maybe worth putting these two together.
//replace edattain=2 if edattain==9 | edattain==0 | edattain==. //alternatives here, it doesn't matter
drop if edattain==.
drop if edattain==9 | edattain==0


collapse (rawsum) balkan yugoslavia bosnia croatia native total=perwt native_emp native_unemp native_inactive (count) nobs=native, by(time edattain `age')

egen code=group(`geo'  edattain  `age')
tsset code time

generate native_lf=native_emp+native_unemp

*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES
generate urate=(native_unemp/native_lf) 

generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)
generate derate2=(native_emp/native) - (L.native_emp/L.native)


gen nobs_tot=nobs+L.nobs
drop nobs
ren nobs nobs

keep durate2 derate2 edattain nobs time code
keep if durate2!=.

save `t1', replace

use "`using'", clear

keep if ENUTS2==113

drop if year==1996 //Middle of the decade not used
drop if country==250 //France doesn't distinguish foreign origin
drop if country==826 //UK has different education codes (it won't matter because there are very few refugees in the data. 

** age selection

keep if age>=`agemin' & age<=`agemax'

** Drop females if sex==1

if ("`sex'"=="1") {
drop if sex==2
}



*DROP IF ACTIVITY IS NIU
drop if empstat==0
*DROPS IF IN SCHOOL OR RETIRED
drop if empstatd==330 | empstatd==343


** Drop observations without occupation or industry information if occupation or industry cells
if ("`geo'"=="occisco") {
drop if occisco>=10
drop if country==756 //Switzerland does not record the occupation of the unemployed
}
if ("`geo'"=="indgen") {
drop if indgen==0
}
if ("`geo'"=="occisco country") {
drop if occisco>=10
drop if country==756 //Switzerland does not record the occupation of the unemployed
}

** TWO VARIABLES TO IDENTIFY countries:

** Country of birth variable: IE (372) PT (620) RO (642) UK (826)
gen balkan=((bplcountry>=43140 & bplcountry<=43144)|(bplcountry==43030)|(bplcountry==43040)|(bplcountry==43110)| (bplcountry==43130)) ///
          //&(country==372|country==620|country==642|country==826) // Maybe worth leaving Slovenia and Macedonia out: (bplcountry==43110)| (bplcountry==43130)
** Nation variable: AT CH GR SP
replace balkan=1 if ((nation>=43140 & nation <=43144) | (nation==43030)|(nation==43040)|(nation==43110)| (nation==43130)) ///
		    //&(country==040|country==756|country==300|country==724) // Slovenia Macedonia: (nation==43110)| (nation==43130)

gen yugoslavia=((bplcountry>=43140 & bplcountry<=43144)&(country==372|country==620|country==642|country==826))|((nation>=43140 & nation <=43144)&(country==040|country==756|country==300|country==724))
gen bosnia=((bplcountry==43030)&(country==372|country==620|country==642|country==826))|((nation==43030)&(country==040|country==756|country==300|country==724))
gen croatia=((bplcountry==43040)&(country==372|country==620|country==642|country==826))|((nation==43040)&(country==040|country==756|country==300|country==724)) 

generate native=(balkan!=1)

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat==3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

replace balkan=balkan*perwt
replace yugoslavia=yugoslavia*perwt
replace bosnia=bosnia*perwt
replace croatia=croatia*perwt
replace native=native*perwt 
//generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)
generate byte agecode=1*(age>=25 & age<=44) + 2*(age>=45 & age<=59)

gen obs=1

gen time=0 if year <= 1995 
replace time=1 if year > 1995 

replace edattain=2 if edattain==1 //Some countries don't have lower level, maybe worth putting these two together.
//replace edattain=2 if edattain==9 | edattain==0 | edattain==. //alternatives here, it doesn't matter
drop if edattain==.
drop if edattain==9 | edattain==0


collapse (rawsum) balkan yugoslavia bosnia croatia native total=perwt native_emp native_unemp native_inactive (count) nobs=native, by(time edattain `age')

egen code=group(`geo'  edattain  `age')
tsset code time

generate native_lf=native_emp+native_unemp

*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES
generate urate=(native_unemp/native_lf) 

generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)
generate derate2=(native_emp/native) - (L.native_emp/L.native)

gen nobs_tot=nobs+L.nobs
drop nobs
ren nobs nobs

keep durate2 derate2 edattain nobs time code
keep if durate2!=.

save `t2', replace

clear
use `t1'
append using `t2'
drop code time

gen order=_n
foreach var of varlist durate2 derate2 { 
	generate `var'_str = string(`var',"%6.2f") 
	replace `var'_str = "" if `var'_str=="." 
}
	generate nobs_str = string(nobs,"%6.0f") 

gen edcode_string = "Primary completed or less" if edattain==2
replace edcode_string = "Secondary completed" if edattain==3
replace edcode_string = "University completed" if edattain==4
drop nobs durate2 derate2 edattain


set obs 8
replace order=order+1 if order>3
replace order=4 in 7
replace edcode_string ="\textbf{Viena:}" in 7
replace order=0 in 8
replace edcode_string ="\textbf{Average in Austria:}" in 8
sort order
drop order

listtex edcode_string durate2_str derate2_str nobs_str  using "$dropbox/tables/sumstat_Europe_dependent.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lccc} \hline" " &  Change in Unemploy. rate &  Change in Employ. rate & Sample size \\ \hline") foot("\hline \end{tabular}")

keep edcode_string durate2_str derate2_str nobs_str 
order edcode_string durate2_str derate2_str nobs_str 
export excel using "$dropbox/tables/sumstat_Europe_dependent.xls", replace

end

cap program drop aggregate_data //This program aggregates the data to the appropriate cell
program define aggregate_data

syntax using/,  geo(string) [agemin(integer 1) agemax(integer 1)  sex(string) age(string) restriction(string) education(string)]  

use "`using'", clear

drop if year==1996 //Middle of the decade not used
drop if country==250 //France doesn't distinguish foreign origin
drop if country==826 //UK has different education codes (it won't matter because there are very few refugees in the data. 

** age selection

keep if age>=`agemin' & age<=`agemax'

** Drop females if sex==1

if ("`sex'"=="1") {
drop if sex==2
}

if ("`restriction'"=="Austria") {
keep if country==40
}

if ("`restriction'"=="Switzerland") {
keep if country==756
}

if ("`restriction'"=="Austria and Switzerland") {
keep if country==756 | country==40
}

*DROP IF ACTIVITY IS NIU
drop if empstat==0
*DROPS IF IN SCHOOL OR RETIRED
drop if empstatd==330 | empstatd==343


** Drop observations without occupation or industry information if occupation or industry cells
if ("`geo'"=="occisco") {
drop if occisco>=10
drop if country==756 //Switzerland does not record the occupation of the unemployed
}
if ("`geo'"=="indgen") {
drop if indgen==0
}
if ("`geo'"=="occisco country") {
drop if occisco>=10
drop if country==756 //Switzerland does not record the occupation of the unemployed
}

** TWO VARIABLES TO IDENTIFY countries:

** Country of birth variable: IE (372) PT (620) RO (642) UK (826)
gen balkan=((bplcountry>=43140 & bplcountry<=43144)|(bplcountry==43030)|(bplcountry==43040)|(bplcountry==43110)| (bplcountry==43130)) ///
          //&(country==372|country==620|country==642|country==826) // Maybe worth leaving Slovenia and Macedonia out: (bplcountry==43110)| (bplcountry==43130)
** Nation variable: AT CH GR SP
replace balkan=1 if ((nation>=43140 & nation <=43144) | (nation==43030)|(nation==43040)|(nation==43110)| (nation==43130)) ///
		    //&(country==040|country==756|country==300|country==724) // Slovenia Macedonia: (nation==43110)| (nation==43130)

gen yugoslavia=((bplcountry>=43140 & bplcountry<=43144)&(country==372|country==620|country==642|country==826))|((nation>=43140 & nation <=43144)&(country==040|country==756|country==300|country==724))
gen bosnia=((bplcountry==43030)&(country==372|country==620|country==642|country==826))|((nation==43030)&(country==040|country==756|country==300|country==724))
gen croatia=((bplcountry==43040)&(country==372|country==620|country==642|country==826))|((nation==43040)&(country==040|country==756|country==300|country==724)) 

generate native=(balkan!=1)

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat==3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

replace balkan=balkan*perwt
replace yugoslavia=yugoslavia*perwt
replace bosnia=bosnia*perwt
replace croatia=croatia*perwt
replace native=native*perwt 
//generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)
generate byte agecode=1*(age>=25 & age<=44) + 2*(age>=45 & age<=59)

gen obs=1

gen time=0 if year <= 1995 
replace time=1 if year > 1995 

replace edattain=2 if edattain==1 //Some countries don't have lower level, maybe worth putting these two together.
//replace edattain=2 if edattain==9 | edattain==0 | edattain==. //alternatives here, it doesn't matter
drop if edattain==.
drop if edattain==9 | edattain==0

if ("`education'"=="aggregate") {
replace edattain=2 if edattain==4
}

collapse (rawsum) balkan yugoslavia bosnia croatia native total=perwt native_emp native_unemp native_inactive (count) nobs=native, by(`geo' time edattain `age')

egen code=group(`geo' edattain  `age')
tsset code time

generate native_lf=native_emp+native_unemp

*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES
generate urate=(native_unemp/native_lf) 

generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)
generate derate2=(native_emp/native) - (L.native_emp/L.native)

*THIS GIVES DISTRIBUTION IN SPACE

/*
local varlist "balkan yugoslavia bosnia croatia"
foreach var of local varlist{
bysort time edattain: egen tot_`var'=sum(`var')
gen distr_`var'=`var'/tot_`var'
tsset code time
gen dtot_`var'=tot_`var'-L.tot_`var'
gen pred_`var'=L.distr_`var' * dtot_`var'
}
*/

//gen pred_balkan2=(L.distr_yugoslavia * dtot_yugoslavia) + (L.distr_bosnia * dtot_bosnia) + (L.distr_croatia * dtot_croatia)


tsset code time

**************************
*BUT WHAT ABOUT THE OTHER GUEST WORKERS
*WE WILL NEED TO ADDRESS THIS ISSUE SOMEHOW
*FOR NOW I WILL IGNORE THEM
***************************

*WE WANT TO DEFINE THE SHOCKS IN TERMS OF THE CORRECT THEORETICAL SPECIFICATION

*IN TIME 0, EVERYONE IS A FRENCH NATIVE
*IN TIME 1, ONLY THE NON-ALGERIANS AND NON-REPATRIATES ARE "NATIVES"
*I WILL DEFINE THE NATIVE CHANGE IN TERMS OF POPULATION TO AVOID ENDOGENEITY
generate nat0=L.total
generate nat1=total-D.balkan
generate dnat=log(nat1/nat0)


*THE SUPPLY SHOCK IS # OF IMMIGRANTS DIVIDED BY "NATIVES" IN 1968
*DREP MEASURES THE NUBMER OF REPATRIATE IMMIGRANTS

generate dbalk=balkan-L.balkan
generate sbalk=balkan/total
//generate balk1=D.sbalk ///Big change in code. Alternative balk1=dbalk/(total-dbalk) no good first stage
generate balk1=dbalk/(total-dbalk)


*CREATING THE INSTRUMENTS
*JUST GET SHARE IN 1962 CELL RELATIVE TO EVERYONE

generate balk0=L.balkan/L.total
//replace pred_balkan=pred_balkan/(total-pred_balkan)


*NOBS IS THE NUMBER OF NATIVES, BOTH WORKING & NON-WORKING, IN CELL;
generate weight=(nobs*L.nobs)/(nobs+L.nobs)


*** Labeling variables

label var durate2 "Change in Unemployment rate"
label var derate2 "Change in Share Employed"

label var balk0 "L. Share from Balkan countries"

label var balk1 "Inflows of Balkan refugees"
label var dnat "Change in cell size"

end


cap program drop regressions
program define regressions

syntax , [geo(string) tablenum(string) age(string) restriction(string) file_name(string)]

//egen fixed_effects=group(`geo' `age')
//egen fixed_effects2=group(`geo' edattain)

** UNEMPLOYMENT RATE

** GRAPHS

reg durate2 i.country [aw=weight]
predict res_durate2, res
label var res_durate2 "Change in Unemployment rate"

if ("`restriction'"=="no") {

two (scatter res_durate2 balk1 [aw=weight] if country==40, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter res_durate2 balk1 [aw=weight] if country==300, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter res_durate2 balk1 [aw=weight] if country==372, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter res_durate2 balk1 [aw=weight] if country==620, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter res_durate2 balk1 [aw=weight] if country==642, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter res_durate2 balk1 [aw=weight] if country==724, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter res_durate2 balk1 [aw=weight] if country==756, msymbol(circle_hollow) msize(vsmall)) ///
	, graphregion(color(white)) legend(off)
graph export "$dropbox/figures/Europe_raw_graph_balk_`tablenum'.png", replace

}



** SHARE EMPLOYED

if ("`tablenum'"!="occ_male") {

** UNEMPLOYMENT RATE

xi: areg balk1 balk0 `age' i.`geo'   if time==1 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/Europe1_`tablenum'.xls", replace tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("Inflows Balk.","OLS")
xi: areg balk1 balk0 dnat `age' i.`geo'   if time==1 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/Europe1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("Inflows Balk.","OLS")
xi: areg durate2 balk0 `age' i.`geo'   if time==1 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Europe1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg derate2 balk0 dnat i.`geo' `age'   if time==1 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Europe1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")

xi: areg durate2 balk1 i.`geo' `age'   if time==1 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Europe2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) replace label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg durate2 balk1 dnat i.`geo' `age'   if time==1 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Europe2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
 
xi: ivreg2 durate2 (balk1 = balk0) `age' i.`geo'   i.edattain if time==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") 
xi: ivreg2 durate2 (balk1 = balk0) dnat `age' i.`geo'   i.edattain if time==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") 


xi: areg derate2 balk1 i.`geo' `age'   if time==1 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Europe4_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) replace label addtext("Education FE","yes" , "Country FE","yes" ) nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: areg derate2 balk1 dnat i.`geo' `age'   if time==1 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Europe4_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes" , "Country FE","yes" ) nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: ivreg2 derate2 (balk1 = balk0) i.`geo' `age'   i.edattain if time==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe4_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes" , "Country FE","yes" ) nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","IV") e(widstat)
xi: ivreg2 derate2 (balk1 = balk0) dnat i.`geo' `age'   i.edattain if time==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe4_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes" , "Country FE","yes" ) nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","IV") e(widstat)

}
else{

** UNEMPLOYMENT RATE

xi: areg balk1 balk0 `age' i.`geo'   if time==1 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/Europe1_`tablenum'.xls", replace tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("Inflows Balk.","OLS")
xi: areg balk1 balk0 dnat `age' i.`geo'   if time==1 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/Europe1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("Inflows Balk.","OLS")
xi: areg durate2 balk0 `age' i.`geo'   if time==1 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Europe1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg derate2 balk0 dnat i.`geo' `age'   if time==1 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Europe1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")

xi: areg durate2 balk1 i.`geo' `age'   if time==1 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Europe2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) replace label addtext("Education FE","yes" , "Country FE","yes" ) nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg durate2 balk1 dnat i.`geo' `age'   if time==1 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/Europe2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes" , "Country FE","yes" ) nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
 
xi: ivreg2 durate2 (balk1 = balk0) `age' i.`geo'   i.edattain if time==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes" , "Country FE","yes" ) nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") e(widstat)
xi: ivreg2 durate2 (balk1 = balk0) dnat `age' i.`geo'   i.edattain if time==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes" , "Country FE","yes" ) nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") e(widstat)


}

drop _I*
export excel using "$dropbox/data/`file_name'.xls",  firstrow(variables) replace nolabel

end


cap program drop regressions_cross_effect
program define regressions_cross_effect

syntax , [geo(string) tablenum(string) age(string) restriction(string) education(string)]


if ("`education'"=="aggregate") {

** GENERATE INTERACTIONS

gen edcode2=(edattain==2)
gen edcode3=(edattain==3)

local varlist "balk1 balk0"
foreach var of local varlist{
forvalues i=2(1)3 {
gen sign = abs(`var')/`var'
gen `var'_aux=`var'*edcode`i'
bysort `geo' time: egen `var'_edcode`i'=max(abs(`var'_aux))
replace `var'_edcode`i' = `var'_edcode`i' * sign if `var'!=0
drop `var'_aux sign
}
}

forvalues i=2(1)3 {
gen sign = abs(dnat)/dnat
gen dnat_aux=dnat*edcode`i'
bysort `geo' time: egen dnat_edcode`i'=max(abs(dnat_aux))
replace dnat_edcode`i' = sign * dnat_edcode`i'
drop dnat_aux sign
}


label var balk1_edcode3 "Inflows from Balkan countries, midlle-skilled" 

** UNEMPLOYMENT RATE

xi: reg durate2 balk1_edcode3 dnat_edc** i.country if time==1 & edattain==3 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe6_`tablenum'.xls", tex(frag) noaster replace  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Unemp.","Middle-skilled","OLS")
xi: reg durate2 balk1_edcode3 dnat_edc** i.country if time==1 & edattain==2 [aw=weight], robust 
outreg2 using "$dropbox/tables/Europe6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Unemp.","non-Middle-skilled","OLS")

xi: ivreg2 durate2 (balk1_edcode3 = balk0_edcode3) dnat_edc** i.country if time==1 & edattain==3 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe6_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Unemp.","Middle-skilled","IV")
xi: ivreg2 durate2 (balk1_edcode3 = balk0_edcode3) dnat_edc** i.country if time==1 & edattain==2 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Unemp.","non-Middle-skilled","IV")

xi: reg derate2 balk1_edcode3 dnat_edc** i.country if time==1 & edattain==3 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe7_`tablenum'.xls", tex(frag) noaster replace  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Middle-skilled","OLS")
xi: reg derate2 balk1_edcode3 dnat_edc** i.country if time==1 & edattain==2 [aw=weight], robust 
outreg2 using "$dropbox/tables/Europe7_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","non-Middle-skilled","OLS")

xi: ivreg2 derate2 (balk1_edcode3 = balk0_edcode3) dnat_edc** i.country if time==1 & edattain==3 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe7_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Middle-skilled","IV")
xi: ivreg2 derate2 (balk1_edcode3 = balk0_edcode3) dnat_edc** i.country if time==1 & edattain==2 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe7_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","non-Middle-skilled","IV")
}
else{
** GENERATE INTERACTIONS

gen edcode2=(edattain==2)
gen edcode3=(edattain==3)
gen edcode4=(edattain==4)

local varlist "balk1 balk0"
foreach var of local varlist{
forvalues i=2(1)4 {
gen sign = abs(`var')/`var'
gen `var'_aux=`var'*edcode`i'
bysort `geo' time: egen `var'_edcode`i'=max(abs(`var'_aux))
replace `var'_edcode`i' = `var'_edcode`i' * sign if `var'!=0
drop `var'_aux sign
}
}

forvalues i=2(1)4 {
gen sign = abs(dnat)/dnat
gen dnat_aux=dnat*edcode`i'
bysort `geo' time: egen dnat_edcode`i'=max(abs(dnat_aux))
replace dnat_edcode`i' = sign * dnat_edcode`i'
drop dnat_aux sign
}


label var balk1_edcode3 "Inflows from Balkan countries, midlle-skilled" 

** UNEMPLOYMENT RATE

xi: reg durate2 balk1_edcode3 dnat_edc** i.country if time==1 & edattain==2 [aw=weight], robust 
outreg2 using "$dropbox/tables/Europe6_`tablenum'.xls", tex(frag) noaster replace nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Unemp.","Low-skilled","OLS")
xi: reg durate2 balk1_edcode3 dnat_edc** i.country if time==1 & edattain==3 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe6_`tablenum'.xls", tex(frag) noaster   nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Unemp.","Middle-skilled","OLS")
xi: reg durate2 balk1_edcode3 dnat_edc** i.country if time==1 & edattain==4 [aw=weight], robust 
outreg2 using "$dropbox/tables/Europe6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Unemp.","High-skilled","OLS")

xi: ivreg2 durate2 (balk1_edcode3 = balk0_edcode3) dnat_edc** i.country if time==1 & edattain==2 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Unemp.","Low-skilled","IV")
xi: ivreg2 durate2 (balk1_edcode3 = balk0_edcode3) dnat_edc** i.country if time==1 & edattain==3 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe6_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Unemp.","Middle-skilled","IV")
xi: ivreg2 durate2 (balk1_edcode3 = balk0_edcode3) dnat_edc** i.country if time==1 & edattain==4 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Unemp.","High-skilled","IV")

xi: reg derate2 balk1_edcode3 dnat_edc** i.country if time==1 & edattain==2 [aw=weight], robust 
outreg2 using "$dropbox/tables/Europe7_`tablenum'.xls", replace tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Low-skilled","OLS")
xi: reg derate2 balk1_edcode3 dnat_edc** i.country if time==1 & edattain==3 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe7_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Middle-skilled","OLS")
xi: reg derate2 balk1_edcode3 dnat_edc** i.country if time==1 & edattain==4 [aw=weight], robust 
outreg2 using "$dropbox/tables/Europe7_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","High-skilled","OLS")

xi: ivreg2 derate2 (balk1_edcode3 = balk0_edcode3) dnat_edc** i.country if time==1 & edattain==2 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe7_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Low-skilled","IV")
xi: ivreg2 derate2 (balk1_edcode3 = balk0_edcode3) dnat_edc** i.country if time==1 & edattain==3 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe7_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Middle-skilled","IV")
xi: ivreg2 derate2 (balk1_edcode3 = balk0_edcode3) dnat_edc** i.country if time==1 & edattain==4 [aw=weight], robust
outreg2 using "$dropbox/tables/Europe7_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","High-skilled","IV")


}


end


cap program drop sumstats //This program investigates the heteroneity of the effect across age groups
program define sumstats


syntax using/,  geo(string) [agemin(integer 1) agemax(integer 1)  sex(string) age(string) ]  

*** SUMMARY STATS TABLE

tempfile data t1 t2 t3 t4 t5 t6 t7 t8

use "`using'", clear

drop if year==1996 //Middle of the decade not used
drop if country==250 //France doesn't distinguish foreign origin
drop if country==826 //UK has different education codes (it won't matter because there are very few refugees in the data. 

** TWO VARIABLES TO IDENTIFY countries:

** Country of birth variable: IE (372) PT (620) RO (642) UK (826)
gen balkan=((bplcountry>=43140 & bplcountry<=43144)|(bplcountry==43030)|(bplcountry==43040)|(bplcountry==43110)| (bplcountry==43130)) ///
          //&(country==372|country==620|country==642|country==826) // Maybe worth leaving Slovenia and Macedonia out: (bplcountry==43110)| (bplcountry==43130)
** Nation variable: AT CH GR SP
replace balkan=1 if ((nation>=43140 & nation <=43144) | (nation==43030)|(nation==43040)|(nation==43110)| (nation==43130)) ///
		    //&(country==040|country==756|country==300|country==724) // Slovenia Macedonia: (nation==43110)| (nation==43130)

gen yugoslavia=((bplcountry>=43140 & bplcountry<=43144)&(country==372|country==620|country==642|country==826))|((nation>=43140 & nation <=43144)&(country==040|country==756|country==300|country==724))
gen bosnia=((bplcountry==43030)&(country==372|country==620|country==642|country==826))|((nation==43030)&(country==040|country==756|country==300|country==724))
gen croatia=((bplcountry==43040)&(country==372|country==620|country==642|country==826))|((nation==43040)&(country==040|country==756|country==300|country==724)) 

generate native=(balkan!=1)

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat==3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

gen time=0 if year <= 1995 
replace time=1 if year > 1995 

drop year 
ren time year

drop if edattain==.
drop if edattain==9 | edattain==0
replace edattain=2 if edattain==1 //Some countries don't have lower level, maybe worth putting these two together.

save `data', replace

use `data', clear

gen balkan_col=perwt / 1000 if balkan==1
gen native_col=perwt / 1000 if native==1

collapse (sum) balkan_col native_col, by(year)

tsset year

gen dbalkan=D.balkan_col
replace balkan_col=dbalkan 
replace native_col = native_col 

gen shock_col= ( balkan_col / native_col ) * 100

drop if year==0
drop dbalkan year

gen varname="All persons (in 1000)"
save `t1', replace


use `data', clear

gen balkan_col=perwt / 1000 if balkan==1 & age>=25 & age<=59
gen native_col=perwt / 1000 if native==1 & age>=25 & age<=59

collapse (sum) balkan_col native_col, by(year)

tsset year

gen dbalkan=D.balkan_col
replace balkan_col=dbalkan 
replace native_col = native_col 
drop if year==0
drop dbalkan year

gen shock_col= ( balkan_col / native_col ) * 100

gen varname="Aged 25-59"
save `t2', replace

use `data', clear

gen balkan_col=perwt / 1000 if balkan==1 & age>=25 & age<=59 & sex==1
gen native_col=perwt / 1000 if native==1 & age>=25 & age<=59 & sex==1

collapse (sum) balkan_col native_col, by(year)

tsset year

gen dbalkan=D.balkan_col
replace balkan_col=dbalkan 
replace native_col = native_col 
drop if year==0
drop dbalkan year

gen shock_col= ( balkan_col / native_col ) * 100

gen varname="Male, Aged 25-59"
save `t3', replace

use `data', clear

gen balkan_col=1 if balkan==1 & age>=25 & age<=59 & sex==1
gen native_col=1 if native==1 & age>=25 & age<=59 & sex==1

collapse (sum) balkan_col native_col, by(year)

tsset year

gen dbalkan=D.balkan_col
replace balkan_col=dbalkan 
replace native_col = native_col 
drop if year==0
drop dbalkan year

gen shock_col= .

gen varname="Sample Size: Male, Aged 25-59"
save `t4', replace

use `data', clear

gen balkan_col=perwt if age>=25 & age<=59 & sex==1 & balkan==1
gen native_col=perwt if age>=25 & age<=59 & sex==1 & native==1

collapse (sum) balkan_col native_col, by(year edattain) 

drop if edattain==0

tsset  edattain year

gen dbalkan=D.balkan_col
replace balkan_col=dbalkan 
replace native_col = native_col 
drop if year==0
drop dbalkan year

gen shock_col= ( balkan_col / native_col ) * 100

local varlist "balkan_col native_col"
foreach var of local varlist{
egen tot_`var' = sum(`var')
replace `var' = ( `var' / tot_`var' ) * 100
drop tot_`var'
}

sort edattain
gen varname="Primary completed or less"
replace varname="Secondary completed" in 2
replace varname="University completed" in 3
save `t5', replace

use `data', clear

gen balkan_col=perwt if age>=25 & age<=59 & sex==1 & balkan==1
gen native_col=perwt if age>=25 & age<=59 & sex==1 & native==1

collapse (sum) balkan_col native_col, by(country year) 

tsset country year

gen dbalkan=D.balkan_col
replace balkan_col=dbalkan 
replace native_col = native_col 
drop if year==0
drop dbalkan year

gen shock_col= ( balkan_col / native_col ) * 100

local varlist "balkan_col native_col"
foreach var of local varlist{
egen tot_`var' = sum(`var')
replace `var' = (`var' / tot_`var') * 100
drop tot_`var'
}


gen varname="Austria"
replace varname="Greece" in 2
replace varname="Ireland" in 3
replace varname="Portugal" in 4
replace varname="Romania" in 5
replace varname="Spain" in 6
replace varname="Switzerland" in 7
save `t6', replace

use `data', clear

gen balkan_col=perwt if age>=25 & age<=59 & sex==1 & balkan==1
gen native_col=perwt if age>=25 & age<=59 & sex==1 & native==1

keep if country==40

collapse (sum) balkan_col native_col, by(ENUTS2 year) 

tsset ENUTS2 year

gen dbalkan=D.balkan_col
replace balkan_col=dbalkan 
replace native_col = native_col 
drop if year==0
drop dbalkan year

gen shock_col= (balkan_col / native_col) * 100

local varlist "balkan_col native_col"
foreach var of local varlist{
egen tot_`var' = sum(`var')
replace `var' = (`var' / tot_`var') * 100
drop tot_`var'
}

gen varname="Burgenland, AUT"
replace varname="Niederosterreich, AUT" in 2
replace varname="Wien, AUT" in 3
replace varname="Karnten, AUT" in 4
replace varname="Steiermark, AUT" in 5
replace varname="Oberosterreich, AUT" in 6
replace varname="Salzburg, AUT" in 7
replace varname="Tirol" in 8
replace varname="Vorarlberg, AUT" in 9
save `t7', replace

use `data', clear

gen balkan_col=perwt if age>=25 & age<=59 & sex==1 & balkan==1
gen native_col=perwt if age>=25 & age<=59 & sex==1 & native==1

keep if country==756

collapse (sum) balkan_col native_col, by(ENUTS2 year) 

tsset ENUTS2 year

gen dbalkan=D.balkan_col
replace balkan_col=dbalkan 
replace native_col = native_col 
drop if year==0
drop dbalkan year

gen shock_col= (balkan_col / native_col) * 100

local varlist "balkan_col native_col"
foreach var of local varlist{
egen tot_`var' = sum(`var')
replace `var' = (`var' / tot_`var') * 100
drop tot_`var'
}



gen varname="Lake Geneva region, SUI"
replace varname="Espace Mittelland, SUI" in 2
replace varname="Northwestern Switzerland, SUI" in 3
replace varname="Zurich, SUI" in 4
replace varname="Eastern Switzerland, SUI" in 5
replace varname="Central Switzerland, SUI" in 6
replace varname="Ticino, SUI" in 7
save `t8', replace


use `t1'
append using `t2'
append using `t3'
append using `t4'
append using `t5'
append using `t6'
append using `t7'
append using `t8'


foreach var of varlist balkan_col native_col shock_col { 
	generate `var'_str = string(`var',"%6.1f") if varname!="Sample Size: Male, Aged 25-59"
	replace `var'_str = string(`var',"%6.0f") if varname=="Sample Size: Male, Aged 25-59"
	replace `var'_str = "" if `var'_str=="."
}
drop balkan_col native_col shock_col

gen order=_n
replace order=order+1 if order>4
set obs 33
replace order=5 in 31
replace varname="&&\\ Percent Male, Aged 25-59 with: & & &\\" in 31
replace order=order+1 if order>8
replace order=9 in 32
replace varname="&&\\ Percent Male, Aged 25-59 living in: & & & \\" in 32
replace order=order+1 if order>16
replace order=17 in 33
replace varname="&&\\ Percent Male, Aged 25-59 within Austria and Switzerland: & & & \\" in 33
sort order
drop order

listtex varname balkan_col native_col shock_col using "$dropbox/tables/sumstat_Europe.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lccc} \hline" " & Migrants from the Balkan War & European natives & Size of the shock \\ \hline") foot("\hline \end{tabular}")

keep varname balkan_col native_col shock_col 
export excel using "$dropbox/tables/sumstat_Europe.xls", replace 

*** FIGURE ON THE BALANCE OF THE SHOCK

use "`using'", clear

drop if year==1996 //Middle of the decade not used
drop if country==250 //France doesn't distinguish foreign origin
drop if country==826 //UK has different education codes (it won't matter because there are very few refugees in the data. 

** age selection

keep if age>=`agemin' & age<=`agemax'

** Drop females if sex==1

if ("`sex'"=="1") {
drop if sex==2
}



*DROP IF ACTIVITY IS NIU
drop if empstat==0
*DROPS IF IN SCHOOL OR RETIRED
drop if empstatd==330 | empstatd==343


** Drop observations without occupation or industry information if occupation or industry cells
if ("`geo'"=="occisco") {
drop if occisco>=10
drop if country==756 //Switzerland does not record the occupation of the unemployed
}
if ("`geo'"=="indgen") {
drop if indgen==0
}
if ("`geo'"=="occisco country") {
drop if occisco>=10
drop if country==756 //Switzerland does not record the occupation of the unemployed
}

** TWO VARIABLES TO IDENTIFY countries:

** Country of birth variable: IE (372) PT (620) RO (642) UK (826)
gen balkan=((bplcountry>=43140 & bplcountry<=43144)|(bplcountry==43030)|(bplcountry==43040)|(bplcountry==43110)| (bplcountry==43130)) ///
          //&(country==372|country==620|country==642|country==826) // Maybe worth leaving Slovenia and Macedonia out: (bplcountry==43110)| (bplcountry==43130)
** Nation variable: AT CH GR SP
replace balkan=1 if ((nation>=43140 & nation <=43144) | (nation==43030)|(nation==43040)|(nation==43110)| (nation==43130)) ///
		    //&(country==040|country==756|country==300|country==724) // Slovenia Macedonia: (nation==43110)| (nation==43130)

gen yugoslavia=((bplcountry>=43140 & bplcountry<=43144)&(country==372|country==620|country==642|country==826))|((nation>=43140 & nation <=43144)&(country==040|country==756|country==300|country==724))
gen bosnia=((bplcountry==43030)&(country==372|country==620|country==642|country==826))|((nation==43030)&(country==040|country==756|country==300|country==724))
gen croatia=((bplcountry==43040)&(country==372|country==620|country==642|country==826))|((nation==43040)&(country==040|country==756|country==300|country==724)) 

generate native=(balkan!=1)

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat==3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

replace balkan=balkan*perwt
replace yugoslavia=yugoslavia*perwt
replace bosnia=bosnia*perwt
replace croatia=croatia*perwt
replace native=native*perwt 
//generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)
generate byte agecode=1*(age>=25 & age<=44) + 2*(age>=45 & age<=59)

gen obs=1

gen time=0 if year <= 1995 
replace time=1 if year > 1995 

replace edattain=2 if edattain==1 //Some countries don't have lower level, maybe worth putting these two together.
//replace edattain=2 if edattain==9 | edattain==0 | edattain==. //alternatives here, it doesn't matter
drop if edattain==.
drop if edattain==9 | edattain==0

collapse (rawsum) balkan yugoslavia bosnia croatia native total=perwt native_emp native_unemp native_inactive (count) nobs=native, by(`geo' time edattain `age')

egen code=group(`geo'  edattain  `age')
tsset code time

generate native_lf=native_emp+native_unemp

*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES

generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)
generate derate2=(native_emp/native) - (L.native_emp/L.native)

tsset code time

**************************
*BUT WHAT ABOUT THE OTHER GUEST WORKERS
*WE WILL NEED TO ADDRESS THIS ISSUE SOMEHOW
*FOR NOW I WILL IGNORE THEM
***************************

*WE WANT TO DEFINE THE SHOCKS IN TERMS OF THE CORRECT THEORETICAL SPECIFICATION

*IN TIME 0, EVERYONE IS A FRENCH NATIVE
*IN TIME 1, ONLY THE NON-ALGERIANS AND NON-REPATRIATES ARE "NATIVES"
*I WILL DEFINE THE NATIVE CHANGE IN TERMS OF POPULATION TO AVOID ENDOGENEITY
generate nat0=L.total
generate nat1=total-D.balkan
generate dnat=log(nat1/nat0)


*THE SUPPLY SHOCK IS # OF IMMIGRANTS DIVIDED BY "NATIVES" IN 1968
*DREP MEASURES THE NUBMER OF REPATRIATE IMMIGRANTS

generate dbalk=balkan-L.balkan
generate sbalk=balkan/total
//generate balk1=D.sbalk ///Big change in code. Alternative balk1=dbalk/(total-dbalk) no good first stage
generate balk1=dbalk/(total-dbalk)


*CREATING THE INSTRUMENTS
*JUST GET SHARE IN 1962 CELL RELATIVE TO EVERYONE

generate balk0=L.balkan/L.total

*NOBS IS THE NUMBER OF NATIVES, BOTH WORKING & NON-WORKING, IN CELL;
generate weight=(nobs*L.nobs)/(nobs+L.nobs)


*** Labeling variables

label var durate2 "Change in Unemployment rate"
label var derate2 "Change in Share Employed"

label var balk0 "L. Share from Balkan countries"

label var balk1 "Inflows of Balkan refugees"
label var dnat "Change in cell size"

local varlist "dbalk total"
foreach var of local varlist{
replace `var'=0 if `var'==.
bysort time `geo' `age': egen tot_`var'=sum(`var')
gen share_`var'=`var'/tot_`var'
}

gen weight_balk=tot_dbalk/tot_total

ren share_dbalk share_balkan

local max=1 //0.05
gen unifrm=runiform()*`max'

if ("`geo'"=="occisco country") {
two (scatter share_balkan share_total [aw=weight_balk] if time==1 &edattain==2 & share_balk>=0 & share_balk<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_balkan share_total [aw=weight_balk] if time==1 &edattain==3 & share_balk>=0 & share_balk<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_balkan share_total [aw=weight_balk] if time==1 &edattain==4 & share_balk>=0 & share_balk<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (lfit unifrm unifrm), ///
    graphregion(color(white)) ytitle("Share Balkan emigres")xtitle("Share natives")legend(off) ///
    yscale(range(0(0.2)1))xscale(range(0(0.2) 1))ylabel(0(.2)1)xlabel(0(.2)1) //yscale(range(0(0.01)0.05))xscale(range(0(0.01)0.05))ylabel(0(0.01)0.05)xlabel(0(0.01)0.05) 
    graph export "$dropbox/figures/distributions_new_balkan_occ.png", replace
   }
else {
two (scatter share_balkan share_total [aw=weight_balk] if time==1 &edattain==2 & share_balk>=0 & share_balk<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_balkan share_total [aw=weight_balk] if time==1 &edattain==3 & share_balk>=0 & share_balk<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_balkan share_total [aw=weight_balk] if time==1 &edattain==4 & share_balk>=0 & share_balk<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (lfit unifrm unifrm), ///
    graphregion(color(white)) ytitle("Share Balkan emigres")xtitle("Share natives")legend(off) ///
    yscale(range(0(0.2)1))xscale(range(0(0.2) 1))ylabel(0(.2)1)xlabel(0(.2)1) //yscale(range(0(0.01)0.05))xscale(range(0(0.01)0.05))ylabel(0(0.01)0.05)xlabel(0(0.01)0.05) 
    graph export "$dropbox/figures/distributions_new_balkan_enuts2.png", replace
}

end



/***********************
** CALLS
***********************/


/***********************
** SUMMARY STATS AND GRAPHS OF DISTRIBUTION OF THE SHOCK
***********************/

sumstats using "$dropbox/source/Europe_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(country ENUTS2) //age(agecode) 

sumstats_dependent using "$dropbox/source/Europe_raw_Census.dta", sex(1) agemin(25) agemax(59) //age(agecode) //Notes: with ENUTS1 and ENUTS2 the results are similar 


** GEOGRAPHY

** Male population age>25 & age<60

aggregate_data using "$dropbox/source/Europe_raw_Census.dta", geo(country ENUTS2) sex(1) agemin(25) agemax(59) restriction(no) //age(agecode) //Notes: with ENUTS1 and ENUTS2 the results are similar 
regressions, tablenum(geo_male) geo(country) restriction(no) file_name(Europe_estimation_data) //age(agecode)

aggregate_data using "$dropbox/source/Europe_raw_Census.dta", geo(country ENUTS2) sex(1) agemin(25) agemax(59) restriction(no) //age(agecode) //Notes: with ENUTS1 and ENUTS2 the results are similar 
regressions_cross_effect, tablenum(geo_male) geo(ENUTS2)  //age(agecode)

** EXTRA CHECKS, NOT IN THE PAPER

//aggregate_data using "$dropbox/source/Europe_raw_Census.dta", geo(country ENUTS2) sex(1) agemin(25) agemax(59) restriction(no) education(aggregate)  //age(agecode) //Notes: with ENUTS1 and ENUTS2 the results are similar 
//regressions_cross_effect, tablenum(geo_male) geo(ENUTS2) education(aggregate)    //age(agecode)


/*
** GEOGRAPHY -- COUNTRY LEVEL

//sumstats using "$dropbox/source/Europe_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(occisco country) //age(agecode) 

** Male population age>25 & age<60

aggregate_data using "$dropbox/source/Europe_raw_Census.dta", geo(country) sex(1) agemin(25) agemax(59) //age(agecode) //Notes: with ENUTS1 and ENUTS2 the results are similar 
regressions, tablenum(geo_country_male) geo(country) //age(agecode)

** OCCUPATION

** Male population age>25 & age<60

aggregate_data using "$dropbox/source/Europe_raw_Census.dta", geo(occisco country) sex(1) agemin(25) agemax(59) //age(agecode) 
regressions, tablenum(occ_male) geo(country) //age(agecode)

