/***********************
** METADATA
***********************/

/****
Created by: George Borjas and Joan Monras
Date: December 2015
Purpose: Read French Census Data

Inputs: French_raw_Census.dta

Outputs: Graphs and regressions on the algerian episode

****/


/***********************
** COMPUTING RESOURCES
***********************/

clear all
set more off
cd ~
if (regexm("`c(pwd)'","/home/joan")==1) {
 global dropbox "/home/joan/Dropbox/Sciences Po/refugees_and_labor_market_borjas_monras" //Joan's Ubuntu laptop
}		

/***********************
** PROGRAMS
***********************/

cap program drop nativity_selection // This programs aggregates the data to the appropriate cells
program define nativity_selection

generate algerian=(nation==13010 & migfr==99)
generate algerian_stock=(nation==13010)
generate rep=(nation==44030 & migfr==99)
generate native=(nation==44030 & migfr~=99)
generate other=1-algerian-rep-native

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat==3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)


replace algerian=algerian*perwt
replace algerian_stock=algerian_stock*perwt
replace rep=rep*perwt
replace other=other*perwt
replace native=native*perwt
replace native_emp=native_emp*perwt
replace native_unemp=native_unemp*perwt
replace native_inactive=native_inactive*perwt

end

cap program drop sumstats_dependent // This programs aggregates the data to the appropriate cells
program define sumstats_dependent

tempfile t1 t2

syntax using/,  geo(string) [agemin(integer 1) agemax(integer 1)  sex(string) age(string) education(string)]  

use "`using'", clear

keep if age>=`agemin' & age<=`agemax'

*DROP WOMEN
if ("`sex'"=="1") {
keep if sex==1
}
*DROP IF ACTIVITY IS NIU
drop if empstat==0
*DROPS IF IN SCHOOL OR RETIRED
drop if empstatd==330 | empstatd==343

if ("`geo'"=="occ") {
drop if occ==99
}

if ("`education'"=="aggregate") {
//keep if edattain == 1 | edattain == 4
replace edattain=2 if edattain>=2
}

nativity_selection

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

collapse (rawsum) algerian algerian_stock rep other native total=perwt native_emp native_unemp native_inactive (count) nobs=native, by(year edattain `age')

egen code=group(edattain  `age')

tsset code year, delta(6)

generate native_lf=native_emp+native_unemp

*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES
generate urate = (native_unemp/native_lf)
generate erate = (native_emp/native)

generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)
generate derate2=(native_emp/native) - (L.native_emp/L.native)

gen nobs_tot=nobs+L.nobs
drop nobs
ren nobs nobs

keep durate2 derate2 edattain nobs year code
save `t1', replace

use "`using'", clear

keep if enuts2==1182

keep if age>=`agemin' & age<=`agemax'

*DROP WOMEN
if ("`sex'"=="1") {
keep if sex==1
}
*DROP IF ACTIVITY IS NIU
drop if empstat==0
*DROPS IF IN SCHOOL OR RETIRED
drop if empstatd==330 | empstatd==343

if ("`geo'"=="occ") {
drop if occ==99
}

if ("`education'"=="aggregate") {
//keep if edattain == 1 | edattain == 4
replace edattain=2 if edattain>=2
}

nativity_selection

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

collapse (rawsum) algerian algerian_stock rep other native total=perwt native_emp native_unemp native_inactive (count) nobs=native, by(year edattain `age')

egen code=group(edattain  `age')

tsset code year, delta(6)

generate native_lf=native_emp+native_unemp

*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES
generate urate = (native_unemp/native_lf)
generate erate = (native_emp/native)

generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)
generate derate2=(native_emp/native) - (L.native_emp/L.native)

gen nobs_tot=nobs+L.nobs
drop nobs
ren nobs nobs

keep durate2 derate2 edattain nobs year code

save `t2', replace


clear
use `t1'
append using `t2'
drop code year
drop if durate2==.

gen order=_n
foreach var of varlist durate2 derate2 { 
	generate `var'_str = string(`var',"%6.2f") 
	replace `var'_str = "" if `var'_str=="." 
}
	generate nobs_str = string(nobs,"%6.0f") 

gen edcode_string = "Less than primary" if edattain==1
replace edcode_string = "Primary completed" if edattain==2
replace edcode_string = "Secondary completed" if edattain==3
replace edcode_string = "University completed" if edattain==4
drop nobs durate2 derate2 edattain

set obs 10
replace order=order+1 if order>4
replace order=5 in 9
replace edcode_string ="\textbf{Provence-Alpes-Cote d'Azur:}" in 9
replace order=0 in 10
replace edcode_string ="\textbf{Average in France:}" in 10
sort order
drop order

listtex edcode_string durate2_str derate2_str nobs_str  using "$dropbox/tables/sumstat_France_dependent.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lccc} \hline" " &  Change in Unemploy. rate &  Change in Employ. rate & Sample size \\ \hline") foot("\hline \end{tabular}")

keep edcode_string durate2_str derate2_str nobs_str  
order edcode_string durate2_str derate2_str nobs_str  
export excel using "$dropbox/tables/sumstat_France_dependent.xls", replace 

end


cap program drop aggregate_data // This programs aggregates the data to the appropriate cells
program define aggregate_data

syntax using/,  geo(string) [agemin(integer 1) agemax(integer 1)  sex(string) age(string) education(string)]  

use "`using'", clear

keep if age>=`agemin' & age<=`agemax'

*DROP WOMEN
if ("`sex'"=="1") {
keep if sex==1
}
*DROP IF ACTIVITY IS NIU
drop if empstat==0
*DROPS IF IN SCHOOL OR RETIRED
drop if empstatd==330 | empstatd==343

if ("`geo'"=="occ") {
drop if occ==99
}

if ("`education'"=="aggregate") {
//keep if edattain == 1 | edattain == 4
replace edattain=2 if edattain>=2
}

nativity_selection

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

*NOTE THAT IN COLLAPSE, THE ALGERIAN, REP, OTHER, NATIVE ARE POPULATION NUMBERS
collapse (rawsum) algerian algerian_stock rep other native total=perwt native_emp native_unemp native_inactive (count) nobs=native, by(`geo' year edattain `age')

egen code=group(`geo'  edattain  `age')

tsset code year, delta(6)

generate native_lf=native_emp+native_unemp

*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES
generate urate = (native_unemp/native_lf)
generate erate = (native_emp/native)

generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)
generate derate2=(native_emp/native) - (L.native_emp/L.native)


**************************
*BUT WHAT ABOUT THE OTHER GUEST WORKERS
*WE WILL NEED TO ADDRESS THIS ISSUE SOMEHOW
*FOR NOW I WILL IGNORE THEM
***************************

*WE WANT TO DEFINE THE SHOCKS IN TERMS OF THE CORRECT THEORETICAL SPECIFICATION

*IN TIME 0, EVERYONE IS A FRENCH NATIVE
*IN TIME 1, ONLY THE NON-ALGERIANS AND NON-REPATRIATES ARE "NATIVES"
*I WILL DEFINE THE NATIVE CHANGE IN TERMS OF POPULATION TO AVOID ENDOGENEITY
generate nat0=L.total
generate nat1=total-rep-algerian
generate dnat=log(nat1/nat0)


*THE SUPPLY SHOCK IS # OF IMMIGRANTS DIVIDED BY "NATIVES" IN 1968
*DREP MEASURES THE NUBMER OF REPATRIATE IMMIGRANTS

generate alg1=algerian/(total-rep-algerian)
generate rep1=rep/(total-rep-algerian)


*CREATING THE INSTRUMENTS
*JUST GET SHARE IN 1962 CELL RELATIVE TO EVERYONE

generate alg0=L.algerian_stock/L.total
generate rep0=L.rep/L.total

*NOBS IS THE NUMBER OF NATIVES, BOTH WORKING & NON-WORKING, IN CELL;
generate weight=(nobs*L.nobs)/(nobs+L.nobs)


*** Labeling variables

label var durate2 "Change in Unemployment rate"
label var derate2 "Change Employment rate"

label var alg0 "L. Share of Algerians"
label var rep0 "L. Share of Repatriates"

label var alg1 "Inflows of Algerians"
label var rep1 "Inflows of Repatriates"

label var dnat "Change in cell size"

end


cap program drop regressions //This program runs the regressions on the aggregated data
program define regressions

syntax ,  geo(string) [tablenum(string) age(string) file_name(string)]


** GRAPHS

two (scatter durate2 alg1 [aw=weight] if edattain==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 alg1 [aw=weight] if edattain==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 alg1 [aw=weight] if edattain==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 alg1 [aw=weight] if edattain==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/France_raw_graph_alg_`tablenum'.png", replace
two (scatter durate2 rep1 [aw=weight] if edattain==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 rep1 [aw=weight] if edattain==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 rep1 [aw=weight] if edattain==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 rep1 [aw=weight] if edattain==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/France_raw_graph_rep_`tablenum'.png", replace



if ("`geo'"!="occ") {

** UNEMPLOYMENT RATE

xi: areg rep1 rep0 alg0 `age' if year==1968 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/France1_`tablenum'.xls", replace tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("Inflows repat.","OLS")
xi: areg alg1 rep0 alg0 `age' if year==1968 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/France1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("Inflows Algerian","OLS")
xi: areg durate2 rep0 alg0 `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg durate2 rep0 alg0 dnat `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")


xi: areg durate2 rep1 alg1 `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) replace label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg durate2 rep1 alg1 dnat `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: ivreg2 durate2 (rep1 alg1 = rep0 alg0) i.edattain `age' if year==1968 [aw=weight], robust
outreg2 using "$dropbox/tables/France2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") 
xi: ivreg2 durate2 (rep1 alg1 = rep0 alg0) dnat i.edattain `age' if year==1968 [aw=weight], robust
outreg2 using "$dropbox/tables/France2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") 

** SHARE EMPLOYED

xi: areg rep1 rep0 alg0 `age' if year==1968 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/France3_`tablenum'.xls", replace tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("Inflows repat.","OLS")
xi: areg alg1 rep0 alg0 `age' if year==1968 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/France3_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("Inflows Algerian","OLS")
xi: areg derate2 rep0 alg0 `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France3_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Emp.","OLS")
xi: areg derate2 rep0 alg0 dnat `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France3_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Emp.","OLS")


xi: areg derate2 rep1 alg1 `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France4_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) replace label addtext("Education FE","yes") nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: areg derate2 rep1 alg1 dnat `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France4_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes") nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
 xi: ivreg2 derate2 (rep1 alg1 = rep0 alg0) `age' i.edattain if year==1968 [aw=weight], robust
outreg2 using "$dropbox/tables/France4_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes") nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","IV") e(widstat)
xi: ivreg2 derate2 (rep1 alg1 = rep0 alg0) dnat `age' i.edattain if year==1968 [aw=weight], robust
outreg2 using "$dropbox/tables/France4_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes") nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","IV") e(widstat)


** GENERATE INTERACTIONS

gen edcode1=(edattain==1)
gen edcode2=(edattain==2)
gen edcode3=(edattain==3)
gen edcode4=(edattain==4)

forvalues i=1(1)4 {

local varlist "alg rep"
foreach var of local varlist{

gen sign = abs(`var'1)/`var'1
gen `var'1_aux=`var'1*edcode`i'
bysort `geo' year: egen `var'1_edcode`i'=max(abs(`var'1_aux))
replace `var'1_edcode`i' = `var'1_edcode`i' * sign if `var'1!=0
drop `var'1_aux sign

gen sign = abs(`var'0)/`var'0
gen `var'0_aux=`var'0*edcode`i'
bysort `geo' year: egen `var'0_edcode`i'=max(abs(`var'0_aux))
replace `var'0_edcode`i' = `var'0_edcode`i' * sign if `var'0!=0
drop `var'0_aux sign
}

gen sign = abs(dnat)/dnat
gen dnat_aux=dnat*edcode`i'
bysort `geo' year: egen dnat_edcode`i'=max(abs(dnat_aux))
replace dnat_edcode`i' = sign * dnat_edcode`i'
drop dnat_aux sign

}

local varlist "alg rep"
foreach var of local varlist{
forvalues i=1(1)4 {
gen edcode`i'_`var'1_edcode1=edcode`i'*`var'1_edcode1
}
}



label var alg1_edcode1 "Inflows of Algerian, least-skilled" 


xi: reg durate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==1 [aw=weight], robust 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster replace  nonotes nobs nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 1","OLS")
xi: reg durate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==2 [aw=weight], robust 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster nonotes nobs nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 2","OLS")
xi: reg durate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==3 [aw=weight], robust 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster nonotes nobs nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 3","OLS")
xi: reg durate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==4 [aw=weight], robust 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 4","OLS")

xi: ivreg2 durate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==1 [aw=weight], robust 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster  nonotes nor2 nobs drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 1","IV")
xi: ivreg2 durate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==2 [aw=weight], robust 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster nonotes  nor2 nobs drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 2","IV")
xi: ivreg2 durate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==3 [aw=weight], robust 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster nonotes  nor2 nobs drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 3","IV")
xi: ivreg2 durate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==4 [aw=weight], robust 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster nonotes  nor2 nobs drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 4","IV")

xi: reg derate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==1 [aw=weight], robust 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster replace  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 1","OLS")
xi: reg derate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==2 [aw=weight], robust 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 2","OLS")
xi: reg derate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==3 [aw=weight], robust 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 3","OLS")
xi: reg derate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==4 [aw=weight], robust 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 4","OLS")

xi: ivreg2 derate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==1 [aw=weight], robust 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 1","IV")
xi: ivreg2 derate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==2 [aw=weight], robust 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 2","IV")
xi: ivreg2 derate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==3 [aw=weight], robust 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 3","IV")
xi: ivreg2 derate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==4 [aw=weight], robust 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 4","IV")

}
else{

** UNEMPLOYMENT RATE

xi: areg rep1 rep0 alg0 `age' if year==1968 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/France1_`tablenum'.xls", replace tex(frag) noaster  nonotes drop(_I**)  label  noobs nor2 nocons stats(coef se) ctitle("Inflows repat.","OLS")
xi: areg alg1 rep0 alg0 `age' if year==1968 [aw=weight],robust a(edattain)
outreg2 using "$dropbox/tables/France1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label  noobs nor2 nocons stats(coef se) ctitle("Inflows Algerian","OLS")
xi: areg durate2 rep0 alg0 `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label  noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg durate2 rep0 alg0 dnat `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label  noobs nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")


xi: areg durate2 rep1 alg1 `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) replace label addtext("Education FE","yes") nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg durate2 rep1 alg1 dnat `age' if year==1968 [aw=weight], robust a(edattain)
outreg2 using "$dropbox/tables/France2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes") nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: ivreg2 durate2 (rep1 alg1 = rep0 alg0) i.edattain `age' if year==1968 [aw=weight], robust
outreg2 using "$dropbox/tables/France2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes") nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") e(widstat)
xi: ivreg2 durate2 (rep1 alg1 = rep0 alg0) dnat i.edattain `age' if year==1968 [aw=weight], robust
outreg2 using "$dropbox/tables/France2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**)  label addtext("Education FE","yes") nor2 nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") e(widstat)

}


export excel using "$dropbox/data/`file_name'.xls",  firstrow(variables) replace nolabel

end


cap program drop regressions_cross_effect 
program define regressions_cross_effect

syntax ,  geo(string) [tablenum(string) age(string) education(string)]

** GRAPHS


if ("`education'"!="aggregate") {


** GENERATE INTERACTIONS

gen edcode1=(edattain==1)
gen edcode2=(edattain==2)
gen edcode3=(edattain==3)
gen edcode4=(edattain==4)

forvalues i=1(1)4 {

local varlist "alg rep"
foreach var of local varlist{

gen sign = abs(`var'1)/`var'1
gen `var'1_aux=`var'1*edcode`i'
bysort `geo' year: egen `var'1_edcode`i'=max(abs(`var'1_aux))
replace `var'1_edcode`i' = `var'1_edcode`i' * sign if `var'1!=0
drop `var'1_aux sign

gen sign = abs(`var'0)/`var'0
gen `var'0_aux=`var'0*edcode`i'
bysort `geo' year: egen `var'0_edcode`i'=max(abs(`var'0_aux))
replace `var'0_edcode`i' = `var'0_edcode`i' * sign if `var'0!=0
drop `var'0_aux sign
}

gen sign = abs(dnat)/dnat
gen dnat_aux=dnat*edcode`i'
bysort `geo' year: egen dnat_edcode`i'=max(abs(dnat_aux))
replace dnat_edcode`i' = sign * dnat_edcode`i'
drop dnat_aux sign

}

local varlist "alg rep"
foreach var of local varlist{
forvalues i=1(1)4 {
gen edcode`i'_`var'1_edcode1=edcode`i'*`var'1_edcode1
}
}



label var alg1_edcode1 "Inflows of Algerian, least-skilled" 


xi: ivreg2 durate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==1 [aw=weight], 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster replace  nonotes noobs nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 1","OLS")
xi: ivreg2 durate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==2 [aw=weight], 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster nonotes noobs nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 2","OLS")
xi: ivreg2 durate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==3 [aw=weight], 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster nonotes noobs nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 3","OLS")
xi: ivreg2 durate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==4 [aw=weight], 
outreg2 using "$dropbox/tables/France5_`tablenum'.xls", tex(frag) noaster nonotes  noobs nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 4","OLS")

xi: ivreg2 durate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==1 [aw=weight], 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", replace tex(frag) noaster noobs nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 1","IV")
xi: ivreg2 durate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==2 [aw=weight], 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 noobs drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 2","IV")
xi: ivreg2 durate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==3 [aw=weight], 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 noobs drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 3","IV")
xi: ivreg2 durate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==4 [aw=weight], 
outreg2 using "$dropbox/tables/France6_`tablenum'.xls", tex(frag) noaster nonotes  nor2 noobs drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 4","IV")

xi: ivreg2 derate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==1 [aw=weight], 
outreg2 using "$dropbox/tables/France7_`tablenum'.xls", tex(frag) noaster replace noobs  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emp.","Edu. code 1","OLS")
xi: ivreg2 derate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==2 [aw=weight], 
outreg2 using "$dropbox/tables/France7_`tablenum'.xls", tex(frag) noaster nonotes noobs nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emp.","Edu. code 2","OLS")
xi: ivreg2 derate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==3 [aw=weight], 
outreg2 using "$dropbox/tables/France7_`tablenum'.xls", tex(frag) noaster nonotes noobs nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emp.","Edu. code 3","OLS")
xi: ivreg2 derate2 alg1_edcode1 dnat_edcode** if year==1968 & edattain==4 [aw=weight], 
outreg2 using "$dropbox/tables/France7_`tablenum'.xls", tex(frag) noaster nonotes noobs nor2 drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emp.","Edu. code 4","OLS")

xi: ivreg2 derate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==1 [aw=weight], 
outreg2 using "$dropbox/tables/France8_`tablenum'.xls", replace tex(frag) noaster  nonotes nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 1","IV")
xi: ivreg2 derate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==2 [aw=weight], 
outreg2 using "$dropbox/tables/France8_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 2","IV")
xi: ivreg2 derate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==3 [aw=weight], 
outreg2 using "$dropbox/tables/France8_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 3","IV")
xi: ivreg2 derate2 (alg1_edcode1 = alg0_edcode1) dnat_edcode** if year==1968 & edattain==4 [aw=weight], 
outreg2 using "$dropbox/tables/France8_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emp.","Edu. code 4","IV")

}

if ("`education'"=="aggregate") {


** GENERATE INTERACTIONS

gen edcode1=(edattain==1)
gen edcode2=(edattain==2)

forvalues i=1(1)2 {

local varlist "alg rep"
foreach var of local varlist{

gen sign = abs(`var'1)/`var'1
gen `var'1_aux=`var'1*edcode`i'
bysort `geo' year: egen `var'1_edcode`i'=max(abs(`var'1_aux))
replace `var'1_edcode`i' = `var'1_edcode`i' * sign if `var'1!=0
drop `var'1_aux sign

gen sign = abs(`var'0)/`var'0
gen `var'0_aux=`var'0*edcode`i'
bysort `geo' year: egen `var'0_edcode`i'=max(abs(`var'0_aux))
replace `var'0_edcode`i' = `var'0_edcode`i' * sign if `var'0!=0
drop `var'0_aux sign
}

gen sign = abs(dnat)/dnat
gen dnat_aux=dnat*edcode`i'
bysort `geo' year: egen dnat_edcode`i'=max(abs(dnat_aux))
replace dnat_edcode`i' = sign * dnat_edcode`i'
drop dnat_aux sign

}

local varlist "alg rep"
foreach var of local varlist{
forvalues i=1(1)2 {
gen edcode`i'_`var'1_edcode1=edcode`i'*`var'1_edcode1
}
}



label var alg1_edcode1 "Inflows of Algerian, least-skilled" 


xi: ivreg2 durate2 alg1_edcode1 rep1_edcode1 dnat_edcode** if year==1968 & edattain==1 [aw=weight], 
outreg2 using "$dropbox/tables/France5a_`tablenum'.xls", tex(frag) noaster replace  nonotes nobs nor2 drop(_I** dnat** rep1_edcode1 rep1)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","HSDO","OLS")
xi: ivreg2 durate2 alg1_edcode1 rep1_edcode1 rep1 dnat_edcode** if year==1968 & edattain==2 [aw=weight], 
outreg2 using "$dropbox/tables/France5a_`tablenum'.xls", tex(frag) noaster nonotes nobs nor2 drop(_I** dnat** rep1_edcode1 rep1)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","non-HSDO","OLS")

xi: ivreg2 durate2 (alg1_edcode1 rep1_edcode1 rep1 = alg0_edcode1 rep0_edcode1 rep0)  dnat_edcode** if year==1968 & edattain==1 [aw=weight], 
outreg2 using "$dropbox/tables/France5a_`tablenum'.xls", tex(frag) noaster  nonotes nor2 nobs drop(_I** dnat** rep1_edcode1 rep1)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","HSDO","IV")
xi: ivreg2 durate2 (alg1_edcode1 rep1_edcode1 rep1 = alg0_edcode1 rep0_edcode1 rep0) dnat_edcode** if year==1968 & edattain==2 [aw=weight], 
outreg2 using "$dropbox/tables/France5a_`tablenum'.xls", tex(frag) noaster nonotes  nor2 nobs drop(_I** dnat** rep1_edcode1 rep1)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","non-HSDO","IV")

xi: ivreg2 derate2 alg1_edcode1 rep1_edcode1 dnat_edcode** if year==1968 & edattain==1 [aw=weight], 
outreg2 using "$dropbox/tables/France6a_`tablenum'.xls", tex(frag) noaster replace  nonotes nor2 drop(_I** dnat** rep1_edcode1 rep1)  label nocons stats(coef se) addtext("Controls for native supply","yes","Controls for Repatriates shock","yes") ctitle("$\Delta$ Nat. Emp.","HSDO","OLS")
xi: ivreg2 derate2 alg1_edcode1 rep1_edcode1 rep1 dnat_edcode** if year==1968 & edattain==2 [aw=weight], 
outreg2 using "$dropbox/tables/France6a_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat** rep1_edcode1 rep1)  label nocons stats(coef se) addtext("Controls for native supply","yes","Controls for Repatriates shock","yes") ctitle("$\Delta$ Nat. Emp.","non-HSDO","OLS")

xi: ivreg2 derate2 (alg1_edcode1 rep1_edcode1 rep1 = alg0_edcode1 rep0_edcode1 rep0) dnat_edcode** if year==1968 & edattain==1 [aw=weight], 
outreg2 using "$dropbox/tables/France6a_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I** dnat** rep1_edcode1 rep1)  label nocons stats(coef se) addtext("Controls for native supply","yes","Controls for Repatriates shock","yes") ctitle("$\Delta$ Nat. Emp.","HSDO","IV")
xi: ivreg2 derate2 (alg1_edcode1 rep1_edcode1 rep1 = alg0_edcode1 rep0_edcode1 rep0) dnat_edcode** if year==1968 & edattain==2 [aw=weight], 
outreg2 using "$dropbox/tables/France6a_`tablenum'.xls", tex(frag) noaster nonotes  nor2 drop(_I** dnat** rep1_edcode1 rep1)  label nocons stats(coef se) addtext("Controls for native supply","yes","Controls for Repatriates shock","yes") ctitle("$\Delta$ Nat. Emp.","non-HSDO","IV")

}


end

cap program drop sumstats //This program investigates the heteroneity of the effect across age groups
program define sumstats


syntax using/,  geo(string) [agemin(integer 1) agemax(integer 1)  sex(string) age(string) ]  

*** SUMMARY STATS TABLE

tempfile data t1 t2 t3 t4 t5 t6 t7

use "`using'", clear

generate algerian=(nation==13010 & migfr==99)
generate algerian_stock=(nation==13010)
generate rep=(nation==44030 & migfr==99)
generate native=(nation==44030 & migfr~=99)
generate other=1-algerian-rep-native

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat==3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

save `data', replace

use `data', clear

gen rep_col=perwt / 1000 if year==1968 & rep==1 
gen algerian_col=perwt / 1000 if year==1968 & algerian==1
gen native_col=perwt / 1000 if year==1968 & native==1

collapse (sum) rep_col algerian_col native_col

gen rep_shock_col = ( rep_col / native_col ) * 100
gen alg_shock_col = ( algerian_col / native_col ) * 100

gen varname="All persons (in 1000)"

save `t1', replace

use `data', clear

gen rep_col=perwt / 1000 if year==1968 & rep==1 & age>=25 & age<=59
gen algerian_col=perwt / 1000 if year==1968 & algerian==1 & age>=25 & age<=59
gen native_col=perwt / 1000 if year==1968 & native==1 & age>=25 & age<=59

collapse (sum) rep_col algerian_col native_col

gen rep_shock_col = ( rep_col / native_col ) * 100
gen alg_shock_col = ( algerian_col / native_col ) * 100

gen varname="Aged 25-59"
save `t2', replace

use `data', clear

gen rep_col=perwt / 1000 if year==1968 & rep==1 & age>=25 & age<=59 & sex==1
gen algerian_col=perwt / 1000 if year==1968 & algerian==1 & age>=25 & age<=59 & sex==1
gen native_col=perwt / 1000 if year==1968 & native==1 & age>=25 & age<=59 & sex==1

collapse (sum) rep_col algerian_col native_col

gen rep_shock_col = ( rep_col / native_col ) * 100
gen alg_shock_col = ( algerian_col / native_col ) * 100

gen varname="Male, Aged 25-59"
save `t3', replace

use `data', clear

gen rep_col=1 if year==1968 & rep==1 & age>=25 & age<=59 & sex==1
gen algerian_col=1 if year==1968 & algerian==1 & age>=25 & age<=59 & sex==1
gen native_col=1 if year==1968 & native==1 & age>=25 & age<=59 & sex==1

collapse (sum) rep_col algerian_col native_col

gen rep_shock_col = .
gen alg_shock_col = .

gen varname="Sample Size: Male, Aged 25-59"
save `t4', replace

use `data', clear

gen rep_col=perwt if year==1968 & age>=25 & age<=59 & sex==1 & rep==1
gen algerian_col=perwt if year==1968 & age>=25 & age<=59 & sex==1 & algerian==1
gen native_col=perwt if year==1968 & age>=25 & age<=59 & sex==1 & native==1

collapse (sum) rep_col algerian_col native_col, by(edattain) 

gen rep_shock_col = ( rep_col / native_col ) * 100
gen alg_shock_col = ( algerian_col / native_col ) * 100

drop if edattain==0

local varlist "rep_col algerian_col native_col"
foreach var of local varlist{
egen tot_`var' = sum(`var')
replace `var' = ( `var' / tot_`var' ) * 100
drop tot_`var'
}

sort edattain
gen varname="Less than primary"
replace varname="Primary completed" in 2
replace varname="Secondary completed" in 3
replace varname="University completed" in 4
save `t5', replace

use `data', clear

gen rep_col=perwt if year==1968 & age>=25 & age<=59 & sex==1 & rep==1
gen algerian_col=perwt if year==1968 & age>=25 & age<=59 & sex==1 & algerian==1
gen native_col=perwt if year==1968 & age>=25 & age<=59 & sex==1 & native==1

collapse (sum) rep_col algerian_col native_col, by(enuts2) 

gen rep_shock_col = ( rep_col / native_col ) * 100
gen alg_shock_col = ( algerian_col / native_col ) * 100

local varlist "rep_col algerian_col native_col"
foreach var of local varlist{
egen tot_`var' = sum(`var')
replace `var' = (`var' / tot_`var' ) * 100
drop tot_`var'
}

keep if enuts2==1110 | enuts2==1141 | enuts2==1171 | enuts2==1182

gen varname="Region Ile de France"
replace varname="Lorraine" in 2
replace varname="Rhone Alpes" in 3
replace varname="Provence-Alpes-Cote d'Azur" in 4
save `t6', replace

use `data', clear

keep if edattain==1
gen rep_col=perwt if year==1968 & age>=25 & age<=59 & sex==1 & rep==1
gen algerian_col=perwt if year==1968 & age>=25 & age<=59 & sex==1 & algerian==1
gen native_col=perwt if year==1968 & age>=25 & age<=59 & sex==1 & native==1

collapse (sum) rep_col algerian_col native_col, by(enuts2) 

gen rep_shock_col = ( rep_col / native_col ) * 100
gen alg_shock_col = ( algerian_col / native_col ) * 100

local varlist "rep_col algerian_col native_col"
foreach var of local varlist{
egen tot_`var' = sum(`var')
replace `var' = ( `var' / tot_`var' ) * 100
drop tot_`var'
}

keep if enuts2==1110 | enuts2==1141 | enuts2==1171 | enuts2==1182

gen varname="Region Ile de France"
replace varname="Lorraine" in 2
replace varname="Rhone Alpes" in 3
replace varname="Provence-Alpes-Cote d'Azur" in 4
save `t7', replace

use `t1'
append using `t2'
append using `t3'
append using `t4'
append using `t5'
append using `t6'
append using `t7'


foreach var of varlist rep_col algerian_col native_col rep_shock_col alg_shock_col { 
	generate `var'_str = string(`var',"%6.1f") if varname!="Sample Size: Male, Aged 25-59"
	replace `var'_str = string(`var',"%6.0f") if varname=="Sample Size: Male, Aged 25-59"
	replace `var'_str = "" if `var'_str=="."
}
drop rep_col algerian_col native_col rep_shock_col alg_shock_col

gen order=_n



set obs 19
replace order=order+1 if order>4
replace order=5 in 17
replace varname="&&&\\ Percent Male, Aged 25-59 with: & & & & & \\" in 17
replace order=order+1 if order>9
replace order=10 in 18
replace varname="&&&\\ Percent Male, Aged 25-59 living in: & & & & & \\" in 18
replace order=order+1 if order>14
replace order=15 in 19
replace varname="&&&\\ Percent low-skilled Male, Aged 25-59 living in: & & & & & \\" in 19
sort order
drop order

listtex varname rep_col algerian_col native_col rep_shock_col alg_shock_col using "$dropbox/tables/sumstat_France.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lccccc} \hline" " &French Repatriates & Algerian Nationals & French natives & Size shock Repatriates & Size shock Algerian \\ \hline") foot("\hline \end{tabular}")

keep varname rep_col algerian_col native_col rep_shock_col alg_shock_col 
order varname rep_col algerian_col native_col rep_shock_col alg_shock_col 
export excel using "$dropbox/tables/sumstat_France.xls", replace 

*** FIGURE ON THE BALANCE OF THE SHOCK

use "`using'", clear

keep if age>=`agemin' & age<=`agemax'

*DROP WOMEN
if ("`sex'"=="1") {
keep if sex==1
}
*DROP IF ACTIVITY IS NIU
drop if empstat==0
*DROPS IF IN SCHOOL OR RETIRED
drop if empstatd==330 | empstatd==343

if ("`geo'"=="occ") {
drop if occ==99
}

nativity_selection

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

*NOTE THAT IN COLLAPSE, THE ALGERIAN, REP, OTHER, NATIVE ARE POPULATION NUMBERS
collapse (rawsum) algerian algerian_stock rep other native total=perwt native_emp native_unemp native_inactive (count) nobs=native, by(`geo' year edattain `age')

egen code=group(`geo'  edattain  `age')

tsset code year, delta(6)

generate native_lf=native_emp+native_unemp

*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES

generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)
generate derate2=(native_emp/native) - (L.native_emp/L.native)


**************************
*BUT WHAT ABOUT THE OTHER GUEST WORKERS
*WE WILL NEED TO ADDRESS THIS ISSUE SOMEHOW
*FOR NOW I WILL IGNORE THEM
***************************

*WE WANT TO DEFINE THE SHOCKS IN TERMS OF THE CORRECT THEORETICAL SPECIFICATION

*IN TIME 0, EVERYONE IS A FRENCH NATIVE
*IN TIME 1, ONLY THE NON-ALGERIANS AND NON-REPATRIATES ARE "NATIVES"
*I WILL DEFINE THE NATIVE CHANGE IN TERMS OF POPULATION TO AVOID ENDOGENEITY
generate nat0=L.total
generate nat1=total-rep-algerian
generate dnat=log(nat1/nat0)


*THE SUPPLY SHOCK IS # OF IMMIGRANTS DIVIDED BY "NATIVES" IN 1968
*DREP MEASURES THE NUBMER OF REPATRIATE IMMIGRANTS

generate alg1=algerian/(total-rep-algerian)
generate rep1=rep/(total-rep-algerian)


*CREATING THE INSTRUMENTS
*JUST GET SHARE IN 1962 CELL RELATIVE TO EVERYONE

generate alg0=L.algerian_stock/L.total
generate rep0=L.rep/L.total

*NOBS IS THE NUMBER OF NATIVES, BOTH WORKING & NON-WORKING, IN CELL;
generate weight=(nobs*L.nobs)/(nobs+L.nobs)


*** Labeling variables

label var durate2 "Unemployment rate"
label var derate2 "Share Employed"

label var alg0 "L. Share of Algerians"
label var rep0 "L. Share of Repatriates"

label var alg1 "Inflows of Algerians"
label var rep1 "Inflows of Repatriates"

label var dnat "Change in cell size"


local varlist "algerian rep total"
foreach var of local varlist{
replace `var'=0 if `var'==.
bysort year `geo' `age': egen tot_`var'=sum(`var')
//bysort year: egen tot_`var'=sum(`var')
gen share_`var'=`var'/tot_`var'
}

gen weight_alg=tot_algerian/tot_total
gen weight_rep=tot_rep/tot_total

local max=1 //0.05
gen unifrm=runiform()*`max'

two (scatter share_rep share_total [aw=weight_rep] if year==1968 &edattain==1 & share_rep>=0 & share_rep<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_rep share_total [aw=weight_rep] if year==1968 &edattain==2 & share_rep>=0 & share_rep<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_rep share_total [aw=weight_rep] if year==1968 &edattain==3 & share_rep>=0 & share_rep<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_rep share_total [aw=weight_rep] if year==1968 &edattain==4 & share_rep>=0 & share_rep<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (lfit unifrm unifrm), ///
    graphregion(color(white)) ytitle("Share repatriates")xtitle("Share natives")legend(off) ///
    yscale(range(0(0.2)1))xscale(range(0(0.2) 1))ylabel(0(.2)1)xlabel(0(.2)1) //yscale(range(0(0.01)0.05))xscale(range(0(0.01)0.05))ylabel(0(0.01)0.05)xlabel(0(0.01)0.05) 
    graph export "$dropbox/figures/distributions_new_repatriates_`geo'.png", replace

two (scatter share_algerian share_total [aw=weight_alg] if year==1968 &edattain==1 & share_algerian>=0 & share_algerian<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_algerian share_total [aw=weight_alg] if year==1968 &edattain==2 & share_algerian>=0 & share_algerian<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_algerian share_total [aw=weight_alg] if year==1968 &edattain==3 & share_algerian>=0 & share_algerian<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_algerian share_total [aw=weight_alg] if year==1968 &edattain==4 & share_algerian>=0 & share_algerian<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (lfit unifrm unifrm), ///
    graphregion(color(white)) ytitle("Share Algerian")xtitle("Share natives")legend(off) ///
    yscale(range(0(0.2)1))xscale(range(0(0.2) 1))ylabel(0(.2)1)xlabel(0(.2)1)  //Alternative: yscale(range(0(0.01)0.05))xscale(range(0(0.01)0.05))ylabel(0(0.01)0.05)xlabel(0(0.01)0.05) 
    graph export "$dropbox/figures/distributions_new_algerian_`geo'.png", replace

reg share_algerian share_total [aw=weight] if year==1968, robust nocons
reg share_rep share_total [aw=weight] if year==1968, robust 
reg share_rep share_total [aw=weight] if year==1968  & share_rep>=0 & share_rep<=1 & share_total>=0 & share_total<=1, nocons
reg share_rep share_total if year==1968  & share_rep>=0 & share_rep<=1 & share_total>=0 & share_total<=1, nocons


end




/***********************
** CALLS
***********************/

/***********************
** SUMMARY STATS AND GRAPHS OF DISTRIBUTION OF THE SHOCK
***********************/

sumstats using "$dropbox/source/French_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(enuts2) //age(agecode) 
sumstats_dependent using "$dropbox/source/French_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(enuts2) //age(agecode) 

/***********************
** MAIN REGRESSIONS
***********************/

/***********************
** DIRECT EFFECT OF IMMIGRATION
***********************/

*GEOGRAHY

** Male population age>25 & age<59 

aggregate_data using "$dropbox/source/French_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(enuts2) //age(agecode) 
regressions, tablenum(geo_male) geo(enuts2) file_name(France_estimation_data) //age(i.agecode)

aggregate_data using "$dropbox/source/French_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(enuts2)  //age(agecode) 
regressions_cross_effect, tablenum(geo_male_disagg) geo(enuts2) //age(i.agecode)

* EXTRA CHECKS< NOT IN THE PAPER

//aggregate_data using "$dropbox/source/French_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(enuts2) education(aggregate) //age(agecode) 
//regressions_cross_effect, tablenum(geo_male) geo(enuts2) education(aggregate) //age(i.agecode)


/*
*OCCUPATIONS

//sumstats using "$dropbox/source/French_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(occ) //age(agecode) 

** Male population age>25 & age<59

aggregate_data using "$dropbox/source/French_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(occ) //age(agecode) 
regressions, tablenum(occ_male) geo(occ) //age(i.agecode)


* GEO-OCCUPATIONS

** Male population age>25 & age<59

aggregate_data using "$dropbox/source/French_raw_Census.dta", agemin(25) agemax(59) sex(1) geo(occ) age(enuts2) 
regressions, tablenum(geo_occ_male) geo(occ) age(i.enuts2)
