/***********************
** METADATA
***********************/

/****
Created by: George Borjas and Joan Monras
Date: December 2016
Purpose: Read Mariel data

Inputs: March cps and Census 1990

Outputs: Graphs and regressions on the Mariel episode

****/


/***********************
** COMPUTING RESOURCES
***********************/

clear all
set more off
cd ~
if (regexm("`c(pwd)'","/home/joan")==1) {
 global dropbox "/home/joan/Dropbox/Sciences Po/refugees_and_labor_market_borjas_monras" //Joan's Ubuntu laptop
}		

cd "$dropbox"

/***********************
** PROGRAMS
***********************/

cap program drop clean_cps // This program cleans CPS data. It's based on Borja's Mariel Boatlift paper
program define clean_cps

use "$dropbox/source/cps_raw_62-15.dta", clear

*THERE ARE 44 METROS IDENTIFIED CONSISTENTLY THROUGH THIS PERIOD, INCLUDING MIAMI
keep if year>=1977 & year<=2004


*SO CALENDAR YEARS OF EARNINGS ARE 1976 THROUGH 1990
*REDEFINES TIME BY CALENDAR YEAR OF EARNINGS
replace year=year-1

*THE ANAHEIM MSA BECAME ORANGE COUNTY MSA IN 1995
replace metarea=4481 if metarea==4482

tempfile tf_goodmsa tf_cps

save `tf_cps'.dta, replace

use "$dropbox/source/goodsmsa.dta", clear //Note: This is Borjas (2017) selection. We use data at metarea 3 digit
replace metarea = int(metarea/10)
keep metarea 
duplicates drop
save `tf_goodmsa'.dta, replace

use `tf_cps'.dta, clear

*KEEPS PERSONS IN THE 44 METRO AREAS THAT ARE DEFINED AT BEGINNING OF PERIOD
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.

merge m:1 metarea using `tf_goodmsa'.dta, keep(3) nogen 


*CARD'S PLACEBO
generate placebo1=(metarea==520 | metarea==3360 | metarea==4480 | metarea==8280)
*SAME EMPLOYMENT GROWTH PLACEBO
generate placebo2=(metarea==4481 | metarea==6840 | metarea==5601 | metarea==7400)


tabulate metarea placebo1 if placebo1==1
tabulate metarea placebo2 if placebo2==1

gen wage_flag=1

*KEEPS EMPLOYED NON-HISPANIC MEN AGED 25-59
*NOT IN SCHOOL VARIABLE STARTS IN 1986, SO NOT USED
drop if gq==2
replace wage_flag=0 if age<25 | age>59
replace wage_flag=0 if sex!=1
replace wage_flag=0 if wkswork1<=0 
*keep if classwly>=21 & classwly<=28

replace wage_flag=0 if hispan!=0

generate male=(sex==1)

*DROPS PERSONS WITH NEGATIVE WTSUPP
replace wage_flag=0 if wtsupp<0


*REDEFINE CATEGORIZED WEEKS FOR PRE-1975 SURVEYS
*INTERVAL MEANS ARE THOSE USED IN MY BOOK IMMIGRATION ECONOMICS
*USES HOURS WORK LAST WEEK AS USUAL HOURS FOR PRE-1975 SURVEYS
replace wkswork1=8.0*(wkswork2==1) + 20.8*(wkswork2==2) + 33.1*(wkswork2==3) + 42.4*(wkswork2==4) + 48.3*(wkswork2==5) + 51.9*(wkswork2==6) if year<=1975 


*OMITS PERSONS WITH 0 EARNINGS, 0 WEEKS, 0 HOURS
generate weeks=wkswork1
replace wage_flag=0 if weeks==0
generate hours=uhrsworkly
replace wage_flag=0 if hours==0 | hours==999


*FIXES TOPCODES
*TOPCDDES DEPEND ON SURVEY YEAR TO MAKE IT SIMPLE
generate survey=year+1
replace wage_flag=0 if incwage<=0
replace wage_flag=0 if incwage==9999999
replace incwage=50000*1.5 if survey>=1968 & survey<=1981 & incwage==50000
replace incwage=75000*1.5 if survey>=1982 & survey<=1984 & incwage==75000
replace incwage=99999*1.5 if survey>=1985 & survey<=1987 & incwage==99999
replace incwage=199998*1.5 if survey>=1988 & survey<=1995 & incwage==199998
drop survey


*CPI DEFLATOR
generate cpi=.
replace cpi =30.2 if year==1962	
replace cpi =30.6 if year==1963	
replace cpi =31 if year==1964	
replace cpi =31.5 if year==1965	
replace cpi =32.4 if year==1966	
replace cpi =33.4 if year==1967	
replace cpi =34.8 if year==1968	
replace cpi =36.7 if year==1969	
replace cpi =38.8 if year==1970	
replace cpi =40.5 if year==1971	
replace cpi =41.8 if year==1972	
replace cpi =44.4 if year==1973	
replace cpi =49.3 if year==1974	
replace cpi =53.8 if year==1975	
replace cpi =56.9 if year==1976	
replace cpi =60.6 if year==1977	
replace cpi =65.2 if year==1978	
replace cpi =72.6 if year==1979	
replace cpi =82.4 if year==1980	
replace cpi =90.9 if year==1981	
replace cpi =96.5 if year==1982	
replace cpi =99.6 if year==1983	
replace cpi =103.9 if year==1984	
replace cpi =107.6 if year==1985	
replace cpi =109.6 if year==1986	
replace cpi =113.6 if year==1987	
replace cpi =118.3 if year==1988	
replace cpi =124 if year==1989	
replace cpi =130.7 if year==1990	
replace cpi =136.2 if year==1991	
replace cpi =140.3 if year==1992	
replace cpi =144.5 if year==1993	
replace cpi =148.2 if year==1994	
replace cpi =152.4 if year==1995	
replace cpi =156.9 if year==1996	
replace cpi =160.5 if year==1997	
replace cpi =163 if year==1998	
replace cpi =166.6 if year==1999	
replace cpi =172.2 if year==2000	
replace cpi =177.1 if year==2001	
replace cpi =179.9 if year==2002	
replace cpi =184 if year==2003	
replace cpi =188.9 if year==2004	
replace cpi =195.3 if year==2005	
replace cpi =201.6 if year==2006	
replace cpi =207.342 if year==2007	
replace cpi =215.303 if year==2008	
replace cpi =214.537 if year==2009	
replace cpi =218.056 if year==2010
replace cpi =224.939 if year==2011	
replace cpi =229.594 if year==2012	
replace cpi =232.957 if year==2013	
replace cpi =236.736 if year==2014	
generate deflator=82.4/cpi
replace incwage=incwage*deflator

generate lweekly=log(incwage/weeks)
generate lannual=log(incwage)
generate lwage=log(incwage/(weeks*hours))

*DROPS OUTLYING WAGE OBSERVATIONS
generate wage=exp(lwage)
replace wage_flag=0 if wage<1.5 | wage>40


*THE COLLEGE GRAD CATEGORY, EDCODE=4, INCLUDES THOSE WITH 4 YEARS OF COLLEGE
*DEGREE UNSPECIFIED IN IPUMS CODE
generate byte edcode=1*(educ<=71) + 2*(educ>=72 & educ<=73) ///
	+ 3*(educ>=80 & educ<=100) + 4*(educ>100)
tabulate educ edcode

*WILL USE 25-59 SAMPLE TO STUDY EARNINGS
replace wage_flag=0 if age<25 | age>59

occ_aggregation

**************************************************;

*THIS CREATES THE MARCH CPS EXTRACT;
*SAVE THE FILE FOR FUTURE USE;
save "$dropbox/data/march_sample.dta", replace

**************************************************;

end


cap program drop nativity_selection // This program defines Cubans in CPS
program define nativity_selection

generate cuban=(hispan==300)
generate native=(hispan!=300)
generate other=1-cuban-native

gen employed=(empstat==10 | empstat==12 | empstat==13)
gen unemployed=(empstat==20 | empstat==21 | empstat==22)
gen inactive=(empstat>=30)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)


replace cuban=cuban*wtsupp
replace other=other*wtsupp
replace native=native*wtsupp
replace native_emp=native_emp*wtsupp
replace native_unemp=native_unemp*wtsupp
replace native_inactive=native_inactive*wtsupp

end

cap program drop occ_aggregation // This program aggregates occupations to a larger level
program define occ_aggregation

gen occ1990_agg = .  // Based on: https://usa.ipums.org/usa/volii/occ1990.shtml
replace occ1990_agg=1 if occ1990>=1 & occ1990<=22
replace occ1990_agg=2 if occ1990>=23 & occ1990<=37
replace occ1990_agg=3 if occ1990==43 
replace occ1990_agg=4 if occ1990>=44 & occ1990<=63
replace occ1990_agg=5 if occ1990>=64 & occ1990<=68
replace occ1990_agg=6 if occ1990>=69 & occ1990<=83
replace occ1990_agg=7 if occ1990>=84 & occ1990<=89
replace occ1990_agg=8 if occ1990>=95 & occ1990<=97
replace occ1990_agg=9 if occ1990>=98 & occ1990<=106
replace occ1990_agg=10 if occ1990>=113 & occ1990<=154
replace occ1990_agg=11 if occ1990>=155 & occ1990<=163
replace occ1990_agg=12 if occ1990>=164 & occ1990<=165
replace occ1990_agg=13 if occ1990>=166 & occ1990<=173
replace occ1990_agg=14 if occ1990>=174 & occ1990<=177
replace occ1990_agg=15 if occ1990>=174 & occ1990<=177
replace occ1990_agg=16 if occ1990>=178 & occ1990<=179
replace occ1990_agg=17 if occ1990>=183 & occ1990<=199
replace occ1990_agg=18 if occ1990>=203 & occ1990<=208
replace occ1990_agg=19 if occ1990>=213 & occ1990<=218
replace occ1990_agg=20 if occ1990>=223 & occ1990<=225
replace occ1990_agg=21 if occ1990>=226 & occ1990<=235
replace occ1990_agg=22 if occ1990>=243 & occ1990<=243
replace occ1990_agg=23 if occ1990>=253 & occ1990<=257
replace occ1990_agg=24 if occ1990>=258 & occ1990<=259
replace occ1990_agg=25 if occ1990>=263 & occ1990<=278
replace occ1990_agg=26 if occ1990>=283 & occ1990<=290
replace occ1990_agg=27 if occ1990>=303 & occ1990<=307
replace occ1990_agg=28 if occ1990>=308 & occ1990<=309
replace occ1990_agg=29 if occ1990>=313 & occ1990<=315
replace occ1990_agg=30 if occ1990>=316 & occ1990<=323
replace occ1990_agg=31 if occ1990>=325 & occ1990<=336
replace occ1990_agg=32 if occ1990>=337 & occ1990<=344
replace occ1990_agg=33 if occ1990>=345 & occ1990<=347
replace occ1990_agg=34 if occ1990>=348 & occ1990<=353
replace occ1990_agg=35 if occ1990>=354 & occ1990<=357
replace occ1990_agg=36 if occ1990>=359 & occ1990<=374
replace occ1990_agg=37 if occ1990>=375 & occ1990<=378
replace occ1990_agg=38 if occ1990>=379 & occ1990<=391
replace occ1990_agg=39 if occ1990>=403 & occ1990<=408
replace occ1990_agg=40 if occ1990>=413 & occ1990<=415
replace occ1990_agg=41 if occ1990>=416 & occ1990<=417
replace occ1990_agg=42 if occ1990>=418 & occ1990<=424
replace occ1990_agg=43 if occ1990>=425 & occ1990<=427
replace occ1990_agg=44 if occ1990>=433 & occ1990<=444
replace occ1990_agg=45 if occ1990>=445 & occ1990<=447
replace occ1990_agg=46 if occ1990>=448 & occ1990<=455
replace occ1990_agg=47 if occ1990>=456 & occ1990<=469
replace occ1990_agg=48 if occ1990>=473 & occ1990<=476
replace occ1990_agg=49 if occ1990>=477 & occ1990<=484
replace occ1990_agg=50 if occ1990>=485 & occ1990<=489
replace occ1990_agg=51 if occ1990>=494 & occ1990<=496
replace occ1990_agg=52 if occ1990>=497 & occ1990<=499
replace occ1990_agg=53 if occ1990>=503 & occ1990<=503
replace occ1990_agg=54 if occ1990>=505 & occ1990<=519
replace occ1990_agg=55 if occ1990>=523 & occ1990<=534
replace occ1990_agg=56 if occ1990>=535 & occ1990<=549
replace occ1990_agg=57 if occ1990>=553 & occ1990<=558
replace occ1990_agg=58 if occ1990>=563 & occ1990<=599
replace occ1990_agg=59 if occ1990>=613 & occ1990<=617
replace occ1990_agg=60 if occ1990>=628 & occ1990<=628
replace occ1990_agg=61 if occ1990>=634 & occ1990<=655
replace occ1990_agg=62 if occ1990>=656 & occ1990<=659
replace occ1990_agg=63 if occ1990>=666 & occ1990<=674
replace occ1990_agg=64 if occ1990>=675 & occ1990<=684
replace occ1990_agg=65 if occ1990>=686 & occ1990<=688
replace occ1990_agg=66 if occ1990>=689 & occ1990<=693
replace occ1990_agg=67 if occ1990>=694 & occ1990<=699
replace occ1990_agg=68 if occ1990>=703 & occ1990<=717
replace occ1990_agg=69 if occ1990>=719 & occ1990<=725
replace occ1990_agg=70 if occ1990>=726 & occ1990<=733
replace occ1990_agg=71 if occ1990>=734 & occ1990<=737
replace occ1990_agg=72 if occ1990>=738 & occ1990<=749
replace occ1990_agg=73 if occ1990>=753 & occ1990<=779
replace occ1990_agg=74 if occ1990>=783 & occ1990<=795
replace occ1990_agg=75 if occ1990>=796 & occ1990<=799
replace occ1990_agg=76 if occ1990>=803 & occ1990<=815
replace occ1990_agg=77 if occ1990>=823 & occ1990<=826
replace occ1990_agg=78 if occ1990>=828 & occ1990<=834
replace occ1990_agg=79 if occ1990>=843 & occ1990<=865
replace occ1990_agg=80 if occ1990>=866 & occ1990<=874
replace occ1990_agg=81 if occ1990>=875 & occ1990<=890
replace occ1990_agg=82 if occ1990>=903 & occ1990<=905
replace occ1990_agg=. if occ1990>=909


gen occ_agg=.
replace occ_agg=1 if occ>=1 & occ<=22
replace occ_agg=2 if occ>=23 & occ<=37
replace occ_agg=3 if occ>=43 & occ<=200
replace occ_agg=4 if occ>=203 & occ<=235
replace occ_agg=5 if occ>=243 & occ<=290
replace occ_agg=6 if occ>=303 & occ<=391
replace occ_agg=7 if occ>=405 & occ<=408
replace occ_agg=8 if occ>=415 & occ<=427
replace occ_agg=9 if occ>=434 & occ<=469
replace occ_agg=10 if occ>=473 & occ<=498
replace occ_agg=11 if occ>=503 & occ<=699
replace occ_agg=12 if occ>=703 & occ<=890


label define occ_agg_lbl 1 `"Executive"'
label define occ_agg_lbl 2 `"Management"', add
label define occ_agg_lbl 3 `"Professional"', add
label define occ_agg_lbl 4 `"Technician"', add
label define occ_agg_lbl 5 `"Sales"', add
label define occ_agg_lbl 6 `"Admin Support"', add
label define occ_agg_lbl 7 `"Private Household"', add
label define occ_agg_lbl 8 `"Protective"', add
label define occ_agg_lbl 9 `"Service"', add
label define occ_agg_lbl 10 `"Farming"', add
label define occ_agg_lbl 11 `"Precision Production"', add
label define occ_agg_lbl 12 `"Operators"', add

end

cap program drop aggregate_data // This programs aggregates the data to cells defined by geo and age
program define aggregate_data

syntax using/,  geo(string) period(string) [agemin(integer 1) agemax(integer 1) num_years(integer 1) sex(string) age(string) education(string) data_set(string)]  

use "`using'", clear

keep if age>=`agemin' & age<=`agemax'

*DROP WOMEN IF SELCETED
if ("`sex'"=="1") {
keep if sex==1
}


if ("`geo'"=="occ_agg") | ("`geo'"=="occ1990") | ("`geo'"=="occ1990_agg")  {
drop if occ1990==999
drop if occ_agg==.
drop if occ1990_agg==.
}

replace lweekly=. if wage_flag==0 
replace lweekly=. if hispan!=0 //Uses only non-Hispanics for wages. Alternative using only non-Cubans: hispan==300. Results are not sensitive to this change.

nativity_selection

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

keep if $period_selection

/* alternative since we are using many years*/
/* Note that we are already making wages comparable by using CPI, but this does not control for overall year shocks. To control for those we can run following regression: */
/* Note that not running the regression is simply pooling various years together */

/*
xi: reg lweekly i.year [aw=wtsupp] //adding linear education specific trends increases s.e. no change in p.e.
predict e_lweekly, res
drop lweekly 
ren e_lweekly lweekly
*/

if ("`education'"=="aggregate") {
replace edcode=2 if edcode>=2 // This allows for a comparison of most affected to leasts affected groups
}

if ("`education'"=="aggregate2") {
replace edcode=3 if edcode>=3 // This allows for a comparison of most affected to leasts affected groups
}


generate period=0 if year<1980
replace period=1 if year>=1980
drop year
rename period year //Collapsing pre and post periods

collapse (rawsum) cuban other native total=wtsupp native_emp native_unemp native_inactive (count) nobs=lweekly (mean) lweekly [aw=wtsupp], by(`geo' year edcode `age')

egen code=group(`geo'  edcode  `age')

tsset code year

generate native_lf=native_emp+native_unemp

*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NATIVES

generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)
generate derate2=(native_emp/native) - (L.native_emp/L.native)
generate dwage2=lweekly - L.lweekly

*THIS GIVES THE NATIVE LABOR SUPPLY

generate nat0=L.total
generate nat1=total-D.cuban
generate dnat=log(nat1/nat0)


*THE SUPPLY SHOCK IS # OF IMMIGRANTS DIVIDED BY "NATIVES" 

generate cub1=D.cuban/(total-D.cuban)

*CREATING THE INSTRUMENTS
*JUST GET LAGGED SHARE IN CELL RELATIVE TO EVERYONE

generate cub0=L.cuban/L.total

*NOBS IS THE NUMBER OF NATIVES, BOTH WORKING & NON-WORKING, IN CELL;
generate weight=(nobs*L.nobs)/(nobs+L.nobs)

*** Labeling variables

label var durate2 "Change in Unemployment rate"
label var derate2 "Change Employment rate"
label var dwage2 "Change in (log) Wages"

label var cub0 "L. Share of Cubans"
label var cub1 "Inflows of Cubans"
label var dnat "Change in cell size"

tempfile tt1 tt2

save `tt1', replace

aggregate_morg_data using "$dropbox/source/cpsorg.dta", agemin(25) agemax(59) sex(1) geo(metarea) period($period_selection) num_years($years) //age(agecode) 
save `tt2', replace

use `tt1', replace
merge 1:1 `geo' year edcode `age' using `tt2', nogen keep(3)

if ("`data_set'"=="morg") {
drop dwage2
ren dwage2_morg dwage2
}


end

cap program drop aggregate_morg_data // This programs aggregates the data to cells defined by geo and age
program define aggregate_morg_data

syntax using/,  geo(string) period(string) [agemin(integer 1) agemax(integer 1) num_years(integer 1) sex(string) age(string) education(string)]  

use "`using'", clear

replace metarea=int(metarea/10)

keep if $period_selection

if ("`education'"=="aggregate") {
replace edcode=2 if edcode>=2 // This allows for a comparison of most affected to leasts affected groups
}

if ("`education'"=="aggregate2") {
replace edcode=3 if edcode>=3 // This allows for a comparison of most affected to leasts affected groups
}

generate period=0 if year<1980
replace period=1 if year>=1980
drop year
rename period year //Collapsing pre and post periods


collapse (mean) lweekly [aw=weight], by(`geo' year edcode `age')

egen code=group(`geo'  edcode  `age')

tsset code year

generate dwage2=lweekly - L.lweekly

*** Labeling variables

label var dwage2 "Change in (log) Wages, morg"

ren dwage2 dwage2_morg

end


cap program drop regressions //This program runs the regressions on the aggregate data
program define regressions

syntax ,  geo(string) [tablenum(string) age(string) census(string) census_file1(string)census_file2(string) education(string) file_name(string)]


if ("`census'"!="yes") {


** REGRESSIONS USING EXCLUSIVELY CPS DATA **

** GRAPHS

two (scatter durate2 cub1 [aw=weight] if edcode==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 cub1 [aw=weight] if edcode==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 cub1 [aw=weight] if edcode==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 cub1 [aw=weight] if edcode==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/Miami_raw_graph_`tablenum'_unemp.png", replace

two (scatter dwage2 cub1 [aw=weight] if edcode==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 cub1 [aw=weight] if edcode==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 cub1 [aw=weight] if edcode==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 cub1 [aw=weight] if edcode==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/Miami_raw_graph_`tablenum'_wage.png", replace
 
 
** WAGES

xi: areg cub1 cub0 `age' if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami1_`tablenum'.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg cub1 cub0 dnat `age'    if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami1_`tablenum'.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg dwage2 cub0 `age'    if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
xi: areg dwage2 cub0 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami1_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")


xi: areg dwage2 cub1  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 replace label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
xi: areg dwage2 cub1 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
 
xi: ivreg2 dwage2 (cub1 = cub0) `age'  i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","IV") 
xi: ivreg2 dwage2 (cub1 = cub0) dnat `age'  i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami2_`tablenum'.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","IV") 


** UNEMPLOYMENT RATE


xi: areg cub1 cub0 `age' if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami3_`tablenum'.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg cub1 cub0 dnat `age'    if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami3_`tablenum'.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg durate2 cub0 `age'    if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami3_`tablenum'.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg durate2 cub0 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami3_`tablenum'.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")


xi: areg durate2 cub1  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami4_`tablenum'.xls", tex(frag) noaster noobs nor2 nonotes drop(_I**) replace label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg durate2 cub1 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami4_`tablenum'.xls", tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
 
xi: ivreg2 durate2 (cub1 = cub0) `age'  i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami4_`tablenum'.xls", tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") 
xi: ivreg2 durate2 (cub1 = cub0) dnat `age'  i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami4_`tablenum'.xls", tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") 

** SHARE UNEMPLOYED


xi: areg cub1 cub0 `age' if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami5_`tablenum'.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg cub1 cub0 dnat `age'    if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami5_`tablenum'.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg derate2 cub0 `age'    if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami5_`tablenum'.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: areg derate2 cub0 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami5_`tablenum'.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")

xi: areg derate2 cub1  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami6_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I**) replace label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: areg derate2 cub1 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami6_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I**)  label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
 
xi: ivreg2 derate2 (cub1 = cub0) `age'    i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami6_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I**)  label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","IV") e(widstat)
xi: ivreg2 derate2 (cub1 = cub0) dnat `age'    i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami6_`tablenum'.xls", tex(frag) noaster  nonotes nor2 drop(_I**)  label addtext("Education FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","IV") e(widstat)
}

** REGRESSIONS USING CENSUS DATA TO COMPUTE THE SIZE OF THE SHOCK AND THE IV **

if ("`census'"=="yes") {

if ("`age'"=="i.agecode") {
local age_merge "age"
}

merge 1:1 edcode metarea year `age_merge' using `census_file1', nogen keep(1 3)
ren cub1_census cub1_1985
ren cub0_census cub0_1985
merge 1:1 edcode metarea year `age_merge' using `census_file2', nogen keep(1 3)
ren cub1_census cub1_1980
ren cub0_census cub0_1980

replace cub1 = cub1_1985
replace cub0 = cub0_1980

** GRAPHS



if ("`education'"!="aggregate") {

two (scatter durate2 cub1 [aw=weight] if edcode==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 cub1 [aw=weight] if edcode==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 cub1 [aw=weight] if edcode==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter durate2 cub1 [aw=weight] if edcode==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/Miami_raw_graph_`tablenum'_census_unemp.png", replace

two (scatter dwage2 cub1 [aw=weight] if edcode==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 cub1 [aw=weight] if edcode==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 cub1 [aw=weight] if edcode==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 cub1 [aw=weight] if edcode==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/Miami_raw_graph_`tablenum'_census_wage.png", replace


reg dwage2 i.edcode i.metarea [aw=weight]
predict dwage2_res, res
label var dwage2_res "Change in (log) Wages"
two (scatter dwage2_res cub1 [aw=weight] if edcode==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2_res cub1 [aw=weight] if edcode==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2_res cub1 [aw=weight] if edcode==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2_res cub1 [aw=weight] if edcode==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/Miami_raw_graph_`tablenum'_census_wage_res.png", replace

}

*********************** OWN EFFECT
 
** WAGES


xi: areg cub1 cub0 `age' if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami1_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg cub1 cub0 dnat `age'    if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami1_`tablenum'_census.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg dwage2 cub0 `age'    if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami1_`tablenum'_census.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
xi: areg dwage2 cub0 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami1_`tablenum'_census.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")


xi: areg dwage2 cub1  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami2_`tablenum'_census.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 replace label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
xi: areg dwage2 cub1 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami2_`tablenum'_census.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","OLS")
 
xi: ivreg2 dwage2 (cub1 = cub0) `age' i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami2_`tablenum'_census.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","IV") 
xi: ivreg2 dwage2 (cub1 = cub0) dnat `age'  i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami2_`tablenum'_census.xls", tex(frag) noaster  nonotes drop(_I**) noobs nor2 label  nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","IV") 

** UNEMPLOYMENT RATE

xi: areg cub1 cub0 `age' if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami3_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg cub1 cub0 dnat `age'    if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami3_`tablenum'_census.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg durate2 cub0 `age'    if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami3_`tablenum'_census.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg durate2 cub0 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami3_`tablenum'_census.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")


xi: areg durate2 cub1  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami4_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I**) replace label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: areg durate2 cub1 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami4_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","OLS")
 
xi: ivreg2 durate2 (cub1 = cub0) `age'    i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami4_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") 
xi: ivreg2 durate2 (cub1 = cub0) dnat `age'    i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami4_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","IV") 

** SHARE UNEMPLOYED

xi: areg cub1 cub0 `age' if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami5_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg cub1 cub0 dnat `age'    if year==1 [aw=weight],robust a(edcode)
outreg2 using "$dropbox/tables/Miami5_`tablenum'_census.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("Inflows cub.","OLS")
xi: areg derate2 cub0 `age'    if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami5_`tablenum'_census.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: areg derate2 cub0 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami5_`tablenum'_census.xls", tex(frag) noaster  nonotes noobs nor2 drop(_I**)  label  nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")

xi: areg derate2 cub1  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami6_`tablenum'_census.xls", tex(frag) noaster  nonotes nor2 drop(_I**) replace label addtext("Education FE","yes", "SMSA FE","yes" ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: areg derate2 cub1 dnat  `age'   if year==1 [aw=weight], robust a(edcode)
outreg2 using "$dropbox/tables/Miami6_`tablenum'_census.xls", tex(frag) noaster  nonotes nor2 drop(_I**)  label addtext("Education FE","yes", "SMSA FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","OLS")
 
xi: ivreg2 derate2 (cub1 = cub0) `age'    i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami6_`tablenum'_census.xls", tex(frag) noaster  nonotes nor2 drop(_I**)  label addtext("Education FE","yes", "SMSA FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","IV") e(widstat)
xi: ivreg2 derate2 (cub1 = cub0) dnat `age'    i.edcode if year==1 [aw=weight], robust
outreg2 using "$dropbox/tables/Miami6_`tablenum'_census.xls", tex(frag) noaster  nonotes nor2 drop(_I**)  label addtext("Education FE","yes", "SMSA FE","yes"  ) nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","IV") e(widstat)

}


drop _I**
export excel using "$dropbox/data/`file_name'.xls",  firstrow(variables) replace

end


cap program drop regressions_cross_effect //This program runs the regressions on the aggregate data
program define regressions_cross_effect

syntax ,  geo(string) [tablenum(string) age(string) census(string) census_file1(string)census_file2(string) education(string)]

if ("`census'"=="yes") { //This option merges the shock computed using Census 1990 data and IV using 1980 Census data

if ("`age'"=="i.agecode") {
local age_merge "age"
}

merge 1:1 edcode metarea year `age_merge' using `census_file1', nogen keep(1 3)
ren cub1_census cub1_1985
ren cub0_census cub0_1985
merge 1:1 edcode metarea year `age_merge' using `census_file2', nogen keep(1 3)
ren cub1_census cub1_1980
ren cub0_census cub0_1980

replace cub1 = cub1_1985
replace cub0 = cub0_1980


******************************************* CROSS EFFECTS

if ("`education'"=="aggregate") { 

** GENERATE INTERACTIONS

gen edcode1=(edcode==1)
gen edcode2=(edcode==2)

forvalues i=1(1)2 {
gen sign = abs(cub1)/cub1
gen cub1_aux=cub1*edcode`i'
bysort `geo' year: egen cub1_edcode`i'=max(abs(cub1_aux))
replace cub1_edcode`i' = cub1_edcode`i' * sign if cub1!=0
drop cub1_aux sign

gen sign = abs(cub0)/cub0
gen cub0_aux=cub0*edcode`i'
bysort `geo' year: egen cub0_edcode`i'=max(abs(cub0_aux))
replace cub0_edcode`i' = cub0_edcode`i' * sign if cub0!=0
drop cub0_aux sign

gen sign = abs(dnat)/dnat
gen dnat_aux=dnat*edcode`i'
bysort `geo' year: egen dnat_edcode`i'=max(abs(dnat_aux))
replace dnat_edcode`i' = sign * dnat_edcode`i'
drop dnat_aux sign
}

forvalues i=1(1)2 {
gen edcode`i'_cub1_edcode1=edcode`i'*cub1_edcode1
}

forvalues i=1(1)2 {
label var edcode`i'_cub1_edcode1 "Inflows of HSDO Cubans x edcode`i'"
label var dnat_edcode`i' "Change in size, edcode`i'"
}

label var cub1_edcode1 "Inflow of Cubans, least-skilled"

******************************************* GRAPHS

two (scatter dwage2 cub1_edcode1 [aw=weight] if edcode==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 cub1_edcode1 [aw=weight] if edcode==2, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/Miami_raw_graph_`tablenum'_census_wage_cross_effect.png", replace


xi: ivreg2 dwage2 cub1_edcode1 dnat_edcode1 dnat_edcode2 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","HSDO","OLS")
xi: ivreg2 dwage2 cub1_edcode1 dnat_edcode1 dnat_edcode2 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","non-HSDO","OLS")

xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","HSDO","IV") 
xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","non-HSDO","IV") 

xi: ivreg2 durate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","HSDO","OLS")
xi: ivreg2 durate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","non-HSDO","OLS")

xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","HSDO","IV") 
xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","non-HSDO","IV") 

xi: ivreg2 derate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", replace tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","HSDO","OLS")
xi: ivreg2 derate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","non-HSDO","OLS")

xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","HSDO","IV") 
xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","non-HSDO","IV") 

}

if ("`education'"=="aggregate2") { 

** GENERATE INTERACTIONS

gen edcode1=(edcode==1)
gen edcode2=(edcode==2)
gen edcode3=(edcode==3)

forvalues i=1(1)3 {
gen sign = abs(cub1)/cub1
gen cub1_aux=cub1*edcode`i'
bysort `geo' year: egen cub1_edcode`i'=max(abs(cub1_aux))
replace cub1_edcode`i' = cub1_edcode`i' * sign if cub1!=0
drop cub1_aux sign

gen sign = abs(cub0)/cub0
gen cub0_aux=cub0*edcode`i'
bysort `geo' year: egen cub0_edcode`i'=max(abs(cub0_aux))
replace cub0_edcode`i' = cub0_edcode`i' * sign if cub0!=0
drop cub0_aux sign

gen sign = abs(dnat)/dnat
gen dnat_aux=dnat*edcode`i'
bysort `geo' year: egen dnat_edcode`i'=max(abs(dnat_aux))
replace dnat_edcode`i' = sign * dnat_edcode`i'
drop dnat_aux sign
}

forvalues i=1(1)3 {
gen edcode`i'_cub1_edcode1=edcode`i'*cub1_edcode1
}

forvalues i=1(1)3 {
label var edcode`i'_cub1_edcode1 "Inflows of HSDO Cubans x edcode`i'"
label var dnat_edcode`i' "Change in size, edcode`i'"
}

label var cub1_edcode1 "Inflow of Cubans, least-skilled"

******************************************* GRAPHS

xi: ivreg2 dwage2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","HSDO","OLS")
xi: ivreg2 dwage2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","HSG","OLS")
xi: ivreg2 dwage2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","College","OLS")

xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","HSDO","IV") 
xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","HSG","IV") 
xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","College","IV") 

xi: ivreg2 durate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","HSDO","OLS")
xi: ivreg2 durate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","HSG","OLS")
xi: ivreg2 durate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","College","OLS")

xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","HSDO","IV") 
xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","HSG","IV") 
xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","College","IV") 

xi: ivreg2 derate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", replace tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","HSDO","OLS")
xi: ivreg2 derate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","HSG","OLS")
xi: ivreg2 derate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","College","OLS")

xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","HSDO","IV") 
xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","HSG","IV") 
xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","College","IV") 

}

if ("`education'"!="aggregate") & ("`education'"!="aggregate2") { 

** GENERATE INTERACTIONS

gen edcode1=(edcode==1)
gen edcode2=(edcode==2)
gen edcode3=(edcode==3)
gen edcode4=(edcode==4)

forvalues i=1(1)4 {
gen sign = abs(cub1)/cub1
gen cub1_aux=cub1*edcode`i'
bysort `geo' year: egen cub1_edcode`i'=max(abs(cub1_aux))
replace cub1_edcode`i' = cub1_edcode`i' * sign if cub1!=0
drop cub1_aux sign

gen sign = abs(cub0)/cub0
gen cub0_aux=cub0*edcode`i'
bysort `geo' year: egen cub0_edcode`i'=max(abs(cub0_aux))
replace cub0_edcode`i' = cub0_edcode`i' * sign if cub0!=0
drop cub0_aux sign

gen sign = abs(dnat)/dnat
gen dnat_aux=dnat*edcode`i'
bysort `geo' year: egen dnat_edcode`i'=max(abs(dnat_aux))
replace dnat_edcode`i' = sign * dnat_edcode`i'
drop dnat_aux sign
}
forvalues i=1(1)4 {
gen edcode`i'_cub1_edcode1=edcode`i'*cub1_edcode1
}

forvalues i=1(1)4 {
label var edcode`i'_cub1_edcode1 "Inflows of HSDO Cubans x edcode`i'"
label var dnat_edcode`i' "Change in size, edcode`i'"
}

label var cub1_edcode1 "Inflow of Cubans, LS"

******************************************* GRAPHS

two (scatter dwage2 cub1_edcode1 [aw=weight] if edcode==1, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 cub1_edcode1 [aw=weight] if edcode==2, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 cub1_edcode1 [aw=weight] if edcode==3, msymbol(circle_hollow) msize(vsmall)) ///
    (scatter dwage2 cub1_edcode1 [aw=weight] if edcode==4, msymbol(circle_hollow) msize(vsmall)), graphregion(color(white)) legend(off)
graph export "$dropbox/figures/Miami_raw_graph_`tablenum'_census_wage_cross_effect.png", replace

** APROACH 1

xi: ivreg2 dwage2 cub1_edcode1 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami7a_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 1","OLS")
xi: ivreg2 dwage2 cub1_edcode1 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami7a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 2","OLS")
xi: ivreg2 dwage2 cub1_edcode1 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami7a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 3","OLS")
xi: ivreg2 dwage2 cub1_edcode1 if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami7a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 4","OLS")

xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami7a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 1","IV") 
xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami7a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 2","IV") 
xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami7a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 3","IV") 
xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami7a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 4","IV") 

xi: ivreg2 durate2 cub1_edcode1 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami8a_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 1","OLS")
xi: ivreg2 durate2 cub1_edcode1 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami8a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 2","OLS")
xi: ivreg2 durate2 cub1_edcode1 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami8a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 3","OLS")
xi: ivreg2 durate2 cub1_edcode1 if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami8a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 4","OLS")

xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami8a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 1","IV") 
xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami8a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 2","IV") 
xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami8a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 3","IV") 
xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami8a_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 4","IV") 

xi: ivreg2 derate2 cub1_edcode1 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami9a_`tablenum'_census.xls", replace tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","Edu. code 1","OLS")
xi: ivreg2 derate2 cub1_edcode1 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami9a_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","Edu. code 2","OLS")
xi: ivreg2 derate2 cub1_edcode1 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami9a_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","Edu. code 3","OLS")
xi: ivreg2 derate2 cub1_edcode1 if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami9a_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","Edu. code 4","OLS")

xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1)if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami9a_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","Edu. code 1","IV") 
xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1)if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami9a_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","Edu. code 2","IV") 
xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1)if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami9a_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","Edu. code 3","IV") 
xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1)if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami9a_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Emplo.","Edu. code 4","IV") 

** APPROACH 2

xi: ivreg2 dwage2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 1","OLS")
xi: ivreg2 dwage2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 2","OLS")
xi: ivreg2 dwage2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 3","OLS")
xi: ivreg2 dwage2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 4","OLS")

xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 1","IV") 
xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 2","IV") 
xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 3","IV") 
xi: ivreg2 dwage2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami7_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Wages","Edu. code 4","IV") 

xi: ivreg2 durate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 1","OLS")
xi: ivreg2 durate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 2","OLS")
xi: ivreg2 durate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 3","OLS")
xi: ivreg2 durate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 4","OLS")

xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 1","IV") 
xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 2","IV") 
xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 3","IV") 
xi: ivreg2 durate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami8_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) ctitle("$\Delta$ Nat. Unemp.","Edu. code 4","IV") 

xi: ivreg2 derate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", replace tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Edu. code 1","OLS")
xi: ivreg2 derate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Edu. code 2","OLS")
xi: ivreg2 derate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Edu. code 3","OLS")
xi: ivreg2 derate2 cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Edu. code 4","OLS")

xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==1 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Edu. code 1","IV") 
xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==2 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Edu. code 2","IV") 
xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==3 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Edu. code 3","IV") 
xi: ivreg2 derate2 (cub1_edcode1=cub0_edcode1) dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1 & edcode==4 [aw=weight],
outreg2 using "$dropbox/tables/Miami9_`tablenum'_census.xls", tex(frag) noaster  nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Controls for native supply","yes") ctitle("$\Delta$ Nat. Emplo.","Edu. code 4","IV") 

*** APPROACH 3, pooled regressions

xi: reg dwage2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami10_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se)  addtext("Education FE","no", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Wages","OLS")
xi: reg dwage2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 i.edcode if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami10_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Education FE","yes", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Wages","OLS")

xi: reg dwage2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami10_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Education FE","no", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Wages","OLS")
xi: reg dwage2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 i.edcode if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami10_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Education FE","yes", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Wages","OLS")

xi: reg durate2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami11_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se)  addtext("Education FE","no", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: reg durate2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 i.edcode if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami11_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Education FE","yes", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Unemp.","OLS")

xi: reg durate2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami11_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Education FE","no", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Unemp.","OLS")
xi: reg durate2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 i.edcode if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami11_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Education FE","yes", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Unemp.","OLS")

xi: reg derate2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami12_`tablenum'_census.xls", replace tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se)  addtext("Education FE","no", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: reg derate2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 i.edcode if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami12_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Education FE","yes", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Emplo.","OLS")

xi: reg derate2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami12_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Education FE","no", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Emplo.","OLS")
xi: reg derate2 edcode1_cub1_edcode1 edcode2_cub1_edcode1 edcode3_cub1_edcode1 edcode4_cub1_edcode1 dnat_edcode1 dnat_edcode2 dnat_edcode3 dnat_edcode4 i.edcode if year==1  [aw=weight], robust
outreg2 using "$dropbox/tables/Miami12_`tablenum'_census.xls", tex(frag) noaster noobs nor2 nonotes drop(_I** dnat**)  label nocons stats(coef se) addtext("Education FE","yes", "SMSA FE","no" ) ctitle("$\Delta$ Nat. Emplo.","OLS")

}

}


end


cap program drop sumstats_dependent
program define sumstats_dependent

tempfile t1 t2

syntax using/,  period(string) [agemin(integer 1) agemax(integer 1) num_years(integer 1) sex(string) age(string) education(string)]  

use "`using'", clear

keep if age>=`agemin' & age<=`agemax'

drop if metarea==500 //Drop Miami, computed in a separate column

*DROP WOMEN IF SELCETED
if ("`sex'"=="1") {
keep if sex==1
}

replace lweekly=. if wage_flag==0 
replace lweekly=. if hispan!=0 //Uses only non-Hispanics for wages. Alternative using only non-Cubans: hispan==300. Results are not sensitive to this change.

nativity_selection

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

keep if $period_selection

if ("`education'"=="aggregate") {
replace edcode=2 if edcode>=2 // This allows for a comparison of most affected to leasts affected groups
}

if ("`education'"=="aggregate2") {
replace edcode=3 if edcode>=3 // This allows for a comparison of most affected to leasts affected groups
}


generate period=0 if year<1980
replace period=1 if year>=1980
drop year
rename period year //Collapsing pre and post periods

collapse (rawsum) cuban other native total=wtsupp native_emp native_unemp native_inactive (count) nobs=lweekly (mean) lweekly [aw=wtsupp], by(year edcode `age')

generate native_lf=native_emp+native_unemp

egen code=group(edcode  `age')
tsset code year
gen dwage2=D.lweekly
generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)

gen nobs_tot=nobs+L.nobs
drop nobs
ren nobs nobs
keep if dwage!=.

save `t1', replace

use "`using'", clear

keep if age>=`agemin' & age<=`agemax'

*DROP WOMEN IF SELCETED
if ("`sex'"=="1") {
keep if sex==1
}

keep if metarea==500 //This is Miami

replace lweekly=. if wage_flag==0 
replace lweekly=. if hispan!=0 //Uses only non-Hispanics for wages. Alternative using only non-Cubans: hispan==300. Results are not sensitive to this change.

nativity_selection

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

keep if $period_selection

if ("`education'"=="aggregate") {
replace edcode=2 if edcode>=2 // This allos for a comparison of most affected to leasts affected groups
}

if ("`education'"=="aggregate2") {
replace edcode=3 if edcode>=3 // This allos for a comparison of most affected to leasts affected groups
}


generate period=0 if year<1980
replace period=1 if year>=1980
drop year
rename period year //Collapsing pre and post periods

collapse (rawsum) cuban other native total=wtsupp native_emp native_unemp native_inactive (count) nobs=lweekly (mean) lweekly [aw=wtsupp], by(year edcode `age')

generate native_lf=native_emp+native_unemp

egen code=group(edcode  `age')
tsset code year
gen dwage2=D.lweekly
generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)

gen nobs_tot=nobs+L.nobs
drop nobs
ren nobs nobs

keep if dwage!=.

save `t2', replace

clear
use `t1'
append using `t2'
drop code year

gen order=_n
foreach var of varlist dwage2 durate2 { 
	generate `var'_str = string(`var',"%6.2f") 
	replace `var'_str = "" if `var'_str=="." 
}
	generate nobs_str = string(nobs,"%6.0f") 

gen edcode_string = "Less than primary" if edcode==1
replace edcode_string = "Primary completed" if edcode==2
replace edcode_string = "Secondary completed" if edcode==3
replace edcode_string = "University completed" if edcode==4
drop nobs durate2 dwage2 edcode

set obs 10
replace order=order+1 if order>4
replace order=5 in 9
replace edcode_string ="\textbf{Miami:}" in 9
replace order=0 in 10
replace edcode_string ="\textbf{US average (excl. Miami):}" in 10
sort order
drop order

listtex edcode_string dwage2_str durate2_str nobs_str  using "$dropbox/tables/sumstat_Miami_dependent.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lccc} \hline" " & Change in (log) wages & Change in Unemploy. rate & Sample size \\ \hline") foot("\hline \end{tabular}")

keep edcode_string dwage2_str durate2_str nobs_str
order edcode_string dwage2_str durate2_str nobs_str
export excel  using "$dropbox/tables/sumstat_Miami_dependent.xls", replace 


end


cap program drop sumstats //This program investigates the heteroneity of the effect across age groups
program define sumstats


syntax using/,  geo(string) period(string) [agemin(integer 1) agemax(integer 1) num_years(integer 1) sex(string) age(string)]  

*** SUMMARY STATS TABLE

tempfile tf_goodmsa

use "$dropbox/source/goodsmsa.dta", clear 
replace metarea = int(metarea/10)
keep metarea 
duplicates drop
save `tf_goodmsa'.dta, replace

tempfile data t1 t2 t3 t4 t5

use "`using'", clear

keep if $period_selection
merge m:1 metarea using "`tf_goodmsa'.dta", nogen keep(3)

generate cuban=(hispan==300)
generate native=(hispan!=300)
generate other=1-cuban-native

gen employed=(empstat==10 | empstat==12 | empstat==13)
gen unemployed=(empstat==20 | empstat==21 | empstat==22)
gen inactive=(empstat>=30)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

generate period=0 if year<1980
replace period=1 if year>=1980
drop year
rename period year //Collapsing pre and post periods

save `data', replace

** All persons, age>=18

use `data', clear

gen cuban_col=wtsupp / 1000 if cuban==1
gen native_col=wtsupp / 1000 if native==1

collapse (sum) cuban_col native_col, by(year)

tsset year

gen dcuban=D.cuban_col
replace cuban_col=dcuban / `num_years' //This is because we are using 3 years
replace native_col = native_col / `num_years'

drop if year==0
drop dcuban year

gen varname="All persons (in 1000)"
save `t1', replace

** All persons, age>=25 & age<=64

use `data', clear

gen cuban_col=wtsupp / 1000 if cuban==1 & age>=25 & age<=59
gen native_col=wtsupp / 1000 if native==1 & age>=25 & age<=59

collapse (sum) cuban_col native_col, by(year)

tsset year

gen dcuban=D.cuban_col
replace cuban_col=dcuban / `num_years' //This is because we are using 3 years
replace native_col = native_col / `num_years'
drop if year==0
drop dcuban year

gen varname="Aged 25-59"
save `t2', replace

** Male, age>=25 & age<=64

use `data', clear

gen cuban_col=wtsupp / 1000 if cuban==1 & age>=25 & age<=59 & sex==1
gen native_col=wtsupp / 1000 if native==1 & age>=25 & age<=59 & sex==1

collapse (sum) cuban_col native_col, by(year)

tsset year

gen dcuban=D.cuban_col
replace cuban_col=dcuban / `num_years' //This is because we are using 3 years
replace native_col = native_col / `num_years'
drop if year==0
drop dcuban year

gen varname="Male, Aged 25-59"
save `t3', replace

** Sample Size: Male, age>=25 & age<=64

use `data', clear

gen cuban_col=1 if cuban==1 & age>=25 & age<=59 & sex==1
gen native_col=1 if native==1 & age>=25 & age<=59 & sex==1

collapse (sum) cuban_col native_col, by(year)

tsset year

gen dcuban=D.cuban_col
//replace cuban_col=dcuban / `num_years' //This is because we are using 3 years
//replace native_col = native_col / `num_years'
drop if year==0
drop dcuban year

gen varname="Sample Size: Male, Aged 25-59"
save `t4', replace

** Education breakdown

use `data', clear

gen cuban_col=wtsupp if age>=25 & age<=59 & sex==1 & cuban==1
gen native_col=wtsupp if age>=25 & age<=59 & sex==1 & native==1

collapse (sum) cuban_col native_col, by(year edcode) 

drop if edcode==0

tsset  edcode year

gen dcuban=D.cuban_col
replace cuban_col=dcuban / `num_years' //This is because we are using 3 years
replace native_col = native_col / `num_years'
drop if year==0
drop dcuban year

local varlist "cuban_col native_col"
foreach var of local varlist{
egen tot_`var' = sum(`var')
replace `var' = (`var' / tot_`var')*100
drop tot_`var'
}

sort edcode
gen varname="Less than primary"
replace varname="Primary completed" in 2
replace varname="Secondary completed" in 3
replace varname="University completed" in 4
save `t5', replace

** Building the summary stats table

use `t1'
append using `t2'
append using `t3'
append using `t4'
append using `t5'

gen order=_n

foreach var of varlist cuban_col native_col { 
	generate `var'_str = string(`var',"%6.2f") if order<4
	replace `var'_str = string(`var',"%6.0f") if order==4
	replace `var'_str = string(`var',"%6.2f") if order>4
	replace `var'_str = "" if `var'_str=="." 
}
drop cuban_col native_col order

gen order=_n
replace order=order+1 if order>4
set obs 9
replace order=5 in 9
replace varname="&&\\ Percent Male, Aged 25-59 with: & &  \\" in 9
sort order
drop order

listtex varname cuban_col native_col using "$dropbox/tables/sumstat_Miami.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lcc} \hline" " & Mariel Boatlift migrants & American natives \\ \hline") foot("\hline \end{tabular}")

keep varname cuban_col native_col
order varname cuban_col native_col
export excel using "$dropbox/tables/sumstat_Miami.xls", replace 

*** FIGURE ON THE BALANCE OF THE SHOCK

use "`using'", clear

keep if age>=`agemin' & age<=`agemax'

*DROP WOMEN
if ("`sex'"=="1") {
keep if sex==1
}

if ("`geo'"=="occ_agg") | ("`geo'"=="occ1990") | ("`geo'"=="occ1990_agg")  {
drop if occ1990==999
drop if occ_agg==.
drop if occ1990_agg==.
}

nativity_selection

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

*NOTE THAT IN COLLAPSE, THE CUBAN, NATIVE ARE POPULATION NUMBERS

replace lweekly=. if wage_flag==0 &  hispan!=0 //Uses only non-Hispanics for wages. Alternative using only non-Cubans: hispan==300. Results are not sensitive to this change.
keep if $period_selection

/* alternative since we are using many years, results don't change

reg lweekly i.year [aw=wtsupp]
predict e_lweekly, res
drop lweekly 
ren e_lweekly lweekly
*/

generate period=0 if year<1980
replace period=1 if year>=1980
drop year
rename period year //Collapsing pre and post periods

collapse (rawsum) cuban other native total=wtsupp native_emp native_unemp native_inactive (count) nobs=native (mean) lweekly [aw=wtsupp], by(`geo' year edcode `age')

egen code=group(`geo'  edcode  `age')

tsset code year

generate native_lf=native_emp+native_unemp

*THIS GIVES THE CHANGE IN UNEMP & EMP RATE OF NON-REPATRIATE FRENCH NATIVES

generate durate2=(native_unemp/native_lf) - (L.native_unemp/L.native_lf)
generate derate2=(native_emp/native) - (L.native_emp/L.native)
generate dwage2=lweekly - L.lweekly

generate dcuban=cuban-L.cuban

generate nat0=L.total
generate nat1=total-D.cuban
generate dnat=log(nat1/nat0)


*THE SUPPLY SHOCK IS # OF IMMIGRANTS DIVIDED BY "NATIVES" IN 1968
*DREP MEASURES THE NUBMER OF REPATRIATE IMMIGRANTS

generate cub1=D.cuban/(total-D.cuban)

*CREATING THE INSTRUMENTS
*JUST GET SHARE IN 1962 CELL RELATIVE TO EVERYONE

generate cub0=L.cuban/L.total

*NOBS IS THE NUMBER OF NATIVES, BOTH WORKING & NON-WORKING, IN CELL;
generate weight=(nobs*L.nobs)/(nobs+L.nobs)

*** Labeling variables

label var durate2 "Change in Unemployment rate"
label var derate2 "Change Employment rate"
label var dwage2 "Change in (log) Wages"

label var cub0 "L. Share of Cubans"
label var cub1 "Inflows of Cubans"
label var dnat "Change in cell size"

*** Computing education distribution within cells

local varlist "dcuban total"
foreach var of local varlist{
replace `var'=0 if `var'==.
bysort year `geo' `age': egen tot_`var'=sum(`var')
//bysort year: egen tot_`var'=sum(`var') //Alternative, compute the overall distribution. Axis of graph should be ameded if alternative used.
tsset code year
gen share_`var'=`var'/tot_`var'
}

gen weight_cuban=tot_dcuban/tot_total
ren share_dcuban share_cuban

local max=1
gen unifrm=runiform()*`max'

two (scatter share_cuban share_total [aw=weight_cuban] if year==1 &edcode==1 & share_cuban>=0 & share_cuban<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_cuban share_total [aw=weight_cuban] if year==1 &edcode==2 & share_cuban>=0 & share_cuban<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_cuban share_total [aw=weight_cuban] if year==1 &edcode==3 & share_cuban>=0 & share_cuban<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_cuban share_total [aw=weight_cuban] if year==1 &edcode==4 & share_cuban>=0 & share_cuban<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (lfit unifrm unifrm), ///
    graphregion(color(white)) ytitle("Share Cubans")xtitle("Share natives")legend(off) ///
    yscale(range(0(0.2)1))xscale(range(0(0.2) 1))ylabel(0(.2)1)xlabel(0(.2)1) //Alternative scale: yscale(range(0(0.01)0.05))xscale(range(0(0.01)0.05))ylabel(0(0.01)0.05)xlabel(0(0.01)0.05) 
    graph export "$dropbox/figures/distributions_cubans_`geo'.png", replace


end

cap program drop sumstats_census_build_table //This program investigates the heteroneity of the effect across age groups
program define sumstats_census_build_table

tempfile data t1 t2 t3 t4 t5

save `data', replace

** All persons

use `data', clear

gen cuban_col=perwt / 1000 if cuban==1
gen native_col=perwt / 1000 if native==1

collapse (sum) cuban_col native_col

gen shock_col = ( cuban_col / native_col ) * 100

gen varname="All persons (in 1000)"
foreach var of varlist cuban_col native_col { 
	generate `var'_str = string(`var',"%6.1f")
	replace `var'_str = "" if `var'_str=="."
}
foreach var of varlist shock_col { 
	generate `var'_str = string(`var',"%6.2f")
	replace `var'_str = "" if `var'_str=="."
}


drop cuban_col native_col shock_col

save `t1', replace

** All persons, aged 25-59

use `data', clear

gen cuban_col=perwt / 1000 if cuban==1 & age>=25 & age<=59
gen native_col=perwt / 1000 if native==1 & age>=25 & age<=59

collapse (sum) cuban_col native_col

gen varname="Aged 25-59"

gen shock_col = ( cuban_col / native_col )* 100

foreach var of varlist cuban_col native_col { 
	generate `var'_str = string(`var',"%6.1f")
	replace `var'_str = "" if `var'_str=="."
}
foreach var of varlist shock_col { 
	generate `var'_str = string(`var',"%6.1f")
	replace `var'_str = "" if `var'_str=="."
}
drop cuban_col native_col shock_col

save `t2', replace

** Male, aged 25-59

use `data', clear

gen cuban_col=perwt / 1000 if cuban==1 & age>=25 & age<=59 & sex==1
gen native_col=perwt / 1000 if native==1 & age>=25 & age<=59 & sex==1

collapse (sum) cuban_col native_col

gen shock_col = ( cuban_col / native_col ) *100

gen varname="Male, Aged 25-59"

foreach var of varlist cuban_col native_col { 
	generate `var'_str = string(`var',"%6.1f")
	replace `var'_str = "" if `var'_str=="."
}
foreach var of varlist shock_col { 
	generate `var'_str = string(`var',"%6.1f")
	replace `var'_str = "" if `var'_str=="."
}
drop cuban_col native_col shock_col

save `t3', replace

** Sample size: Male, aged 25-59

use `data', clear

gen cuban_col=1 if cuban==1 & age>=25 & age<=59 & sex==1
gen native_col=1 if native==1 & age>=25 & age<=59 & sex==1

collapse (sum) cuban_col native_col

gen shock_col = .

gen varname="Sample Size: Male, Aged 25-59"

foreach var of varlist cuban_col native_col { 
	generate `var'_str = string(`var',"%6.0f")
	replace `var'_str = "" if `var'_str=="."
}
foreach var of varlist shock_col { 
	generate `var'_str = string(`var',"%6.1f")
	replace `var'_str = "" if `var'_str=="."
}
drop cuban_col native_col shock_col

save `t4', replace


** Education break down

use `data', clear

gen cuban_col=perwt if age>=25 & age<=59 & sex==1 & cuban==1
gen native_col=perwt if age>=25 & age<=59 & sex==1 & native==1

collapse (sum) cuban_col native_col, by(edcode) 

drop if edcode==0

gen shock_col = ( cuban_col / native_col ) *100

local varlist "cuban_col native_col"
foreach var of local varlist{
egen tot_`var' = sum(`var')
replace `var' =(`var' / tot_`var')*100
drop tot_`var'
}

sort edcode
gen varname="Less than primary"
replace varname="Primary completed" in 2
replace varname="Secondary completed" in 3
replace varname="University completed" in 4

foreach var of varlist cuban_col native_col shock_col { 
	generate `var'_str = string(`var',"%6.1f")
	replace `var'_str = "" if `var'_str=="."
}
drop cuban_col native_col shock_col 

save `t5', replace

use `t1'
append using `t2'
append using `t3'
append using `t4'
append using `t5'

end

cap program drop sumstats_census 
program define sumstats_census

syntax using/,  geo(string) [agemin(integer 1) agemax(integer 1) sex(string) age(string)]  

*** SUMMARY STATS TABLE

tempfile data t1 t2 t3 t4

use "`using'", clear
replace age=age-5

generate cuban=(bpl==250)&(yrimmig==1981)
generate native=(bpl!=250)
generate other=1-cuban-native

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat>=3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

generate edcode=1*(educd<=61) + 2*(educd==62) + 3*(educd>=65 & educd<=90) + 4*(educd>=100) if year==1990
replace edcode=1*(educd<60) + 2*(educd>=60 & educd<65) + 3*(educd>=65 & educd<=90) + 4*(educd>=100) if year==1980 // In the 1980 we cannot distinguish between high school grads and those who did 12 years, but did not graduate


sumstats_census_build_table

gen order=_n
replace order=order+1 if order>4
set obs 9
replace order=5 in 9
replace varname="&&\\ Percent Male, Aged 25-59 with: & & & \\" in 9
sort order
drop order

listtex varname cuban_col native_col shock_col using "$dropbox/tables/sumstat_census_all.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lccc} \hline" " & Mariel Boatlift migrants & American natives & Size of the shock \\ \hline") foot("\hline \end{tabular}")

keep varname cuban_col native_col shock_col
order varname cuban_col native_col shock_col

export excel using "$dropbox/tables/sumstat_census_all.xls", replace


*** SUMMARY STATS TABLE, 38 LOCATIONS

tempfile tf_goodmsa

use "$dropbox/source/goodsmsa.dta", clear 
replace metarea = int(metarea/10)
keep metarea 
duplicates drop
save `tf_goodmsa'.dta, replace

use "`using'", clear

replace age=age-5 //We are considering locations in 1985

drop metarea 
replace migmet5 = int(migmet5/10) if year==1990
ren migmet5 metarea

merge m:1 metarea using "`tf_goodmsa'.dta", nogen keep(3)

replace perwt=2*perwt //not everyone was asked, only half
drop if age<20 //in CPS we are counting 18 or older. Not clear what the cut-off should be here, but it doesn't matter.

generate cuban=(bpl==250)&(yrimmig==1981)
generate native=(bpl!=250)
generate other=1-cuban-native

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat>=3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

generate edcode=1*(educd<=61) + 2*(educd==62) + 3*(educd>=65 & educd<=90) + 4*(educd>=100) if year==1990
replace edcode=1*(educd<60) + 2*(educd>=60 & educd<65) + 3*(educd>=65 & educd<=90) + 4*(educd>=100) if year==1980 // In the 1980 we cannot distinguish between high school grads and those who did 12 years, but did not graduate


sumstats_census_build_table

gen order=_n
replace order=order+1 if order>4
set obs 9
replace order=5 in 9
replace varname="&&\\ Percent Male, Aged 25-59 with: & & & \\" in 9
sort order
drop order

listtex varname cuban_col native_col shock_col  using "$dropbox/tables/sumstat_census.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lccc} \hline" " & Mariel Boatlift migrants & American natives & Size of the shock \\ \hline") foot("\hline \end{tabular}")

keep varname cuban_col native_col shock_col  
order varname cuban_col native_col shock_col  
export excel using "$dropbox/tables/sumstat_census.xls", replace 

*** SUMMARY STATS TABLE - MIAMI ONLY

use "`using'", clear

replace age=age-5 //We are considering locations in 1985

drop metarea 
replace migmet5 = int(migmet5/10) if year==1990
ren migmet5 metarea

keep if metarea==500 //This is Miami

replace perwt=2*perwt //not everyone was asked, only half
drop if age<20 //in CPS we are counting 18 or older. Not clear what the cut-off should be here, but it doesn't matter.

generate cuban=(bpl==250)&(yrimmig==1981)
generate native=(bpl!=250)
generate other=1-cuban-native

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat>=3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

generate edcode=1*(educd<=61) + 2*(educd==62) + 3*(educd>=65 & educd<=90) + 4*(educd>=100) if year==1990
replace edcode=1*(educd<60) + 2*(educd>=60 & educd<65) + 3*(educd>=65 & educd<=90) + 4*(educd>=100) if year==1980 // In the 1980 we cannot distinguish between high school grads and those who did 12 years, but did not graduate

sumstats_census_build_table

gen order=_n
replace order=order+1 if order>4
set obs 9
replace order=5 in 9
replace varname="&&\\ Percent Male, Aged 25-59 with: & & & \\" in 9
sort order
drop order

listtex varname cuban_col native_col shock_col using "$dropbox/tables/sumstat_Miami_census.tex", replace ///
rstyle(tabular) head("\begin{tabular}{lccc} \hline" " & Mariel Boatlift migrants & American natives & Size of the shock \\ \hline") foot("\hline \end{tabular}")

keep varname cuban_col native_col shock_col  
order varname cuban_col native_col shock_col  
export excel using "$dropbox/tables/sumstat_Miami_census.xls", replace 


** FIGURE ON THE BALANCE OF THE SHOCK

tempfile tf_goodmsa

use "$dropbox/source/goodsmsa.dta", clear 
replace metarea = int(metarea/10)
keep metarea 
duplicates drop
save `tf_goodmsa'.dta, replace

use "`using'", clear

if ("`geo'"=="migmet5") {
replace age=age-5 //We are considering locations in 1985
}

//occ_aggregation

keep if age>=`agemin' & age<=`agemax'

if ("`sex'"=="1") {
keep if sex==1
}
if ("`geo'"=="occ_agg") | ("`geo'"=="occ1990") | ("`geo'"=="occ1990_agg")  {
drop if occ1990==999
drop if occ_agg==.
drop if occ1990_agg==.
}

nativity_selection_census

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

generate edcode=1*(educd<=61) + 2*(educd==62) + 3*(educd>=65 & educd<=90) + 4*(educd>=100) if year==1990
replace edcode=1*(educd<60) + 2*(educd>=60 & educd<65) + 3*(educd>=65 & educd<=90) + 4*(educd>=100) if year==1980 // In the 1980 we cannot distinguish between high school grads and those who did 12 years, but did not graduate

replace `geo' = int(`geo'/10) if year==1990 //migmet5 is 4 digit code, this makes it to 3 digit code.

collapse (rawsum) cuban other native total=perwt native_emp native_unemp native_inactive (count) nobs=native, by(`geo' year edcode `age')

ren `geo' metarea
merge m:1 metarea using `tf_goodmsa'.dta, keep(3) 
ren metarea `geo'

egen code=group(`geo'  edcode  `age')

tsset code year

generate native_lf=native_emp+native_unemp

generate nat1_census=total-cuban
generate nat0_census=total

generate cub1_census=cuban/(total-cuban)
generate cub0_census=cuban/(total)

replace year=1 //Makes sure to assign it to post-shock period.

*** Labeling variables

label var cub1_census "Inflows of Cubans, Census"
label var cub0_census "L.Share of Cubans, Census"

*** Computing education distribution within cells


local varlist "cuban total"
foreach var of local varlist{
replace `var'=0 if `var'==.
bysort year `geo' `age': egen tot_`var'=sum(`var')
//bysort year: egen tot_`var'=sum(`var') //Alternative, compute the overall distribution. Axis of graph should be ameded if alternative used.
tsset code year
gen share_`var'=`var'/tot_`var'
}

gen weight_cuban=tot_cuban/tot_total

local max=1
gen unifrm=runiform()*`max'

two (scatter share_cuban share_total [aw=weight_cuban] if year==1 &edcode==1 & share_cuban>=0 & share_cuban<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_cuban share_total [aw=weight_cuban] if year==1 &edcode==2 & share_cuban>=0 & share_cuban<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_cuban share_total [aw=weight_cuban] if year==1 &edcode==3 & share_cuban>=0 & share_cuban<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (scatter share_cuban share_total [aw=weight_cuban] if year==1 &edcode==4 & share_cuban>=0 & share_cuban<=`max' & share_total>=0 & share_total<=`max', msymbol(circle_hollow) msize(vsmall)) ///
    (lfit unifrm unifrm), ///
    graphregion(color(white)) ytitle("Share Cubans")xtitle("Share natives")legend(off) ///
    yscale(range(0(0.2)1))xscale(range(0(0.2) 1))ylabel(0(.2)1)xlabel(0(.2)1) //Alternative scale: yscale(range(0(0.01)0.05))xscale(range(0(0.01)0.05))ylabel(0(0.01)0.05)xlabel(0(0.01)0.05) 
    graph export "$dropbox/figures/distributions_cubans_`geo'_census.png", replace

end


cap program drop nativity_selection_census 
program define nativity_selection_census

generate imm=(citizen==2 | citizen==3)
generate native=(imm==0) if year==1990
replace native=(bpl!=250) if year==1980

generate cuban=(bpl==250)&(yrimmig==1981) if year==1990 //In 1990 we want Cubans that arrived in 1981
replace cuban=(bpl==250) if year==1980 //In 1980 we want stocks of Cubans

generate recent=(imm==1 & bpl~=250 & yrimmig>=1980 & yrimmig<=1985 & year==1990)
replace recent=1 if imm==1 & bpl==250 & yrimmig>1981 & yrimmig<=1985 & year==1990
generate other=1-cuban-native-recent

gen employed=(empstat==1)
gen unemployed=(empstat==2)
gen inactive=(empstat>=3)

generate native_emp=(employed==1 & native==1)
generate native_unemp=(unemployed==1 & native==1)
generate native_inactive=(inactive==1 & native==1)

replace cuban=cuban*perwt
replace recent=recent*perwt
replace other=other*perwt
replace native=native*perwt
replace native_emp=native_emp*perwt
replace native_unemp=native_unemp*perwt
replace native_inactive=native_inactive*perwt

//keep if wkswork1>0 & year==1990

end


cap program drop aggregate_census_data // This programs aggregates the data to the appropriate cells
program define aggregate_census_data

syntax using/,  geo(string) [agemin(integer 1) agemax(integer 1) sex(string) age(string) saveas(string) education(string)]  

tempfile tf_goodmsa

use "$dropbox/source/goodsmsa.dta", clear 
replace metarea = int(metarea/10)
keep metarea 
duplicates drop
save `tf_goodmsa'.dta, replace

use "`using'", clear

if ("`geo'"=="migmet5") {
replace age=age-5 //We are considering locations in 1985
replace perwt=perwt*2
}

//occ_aggregation

keep if age>=`agemin' & age<=`agemax'

if ("`sex'"=="1") {
keep if sex==1
}


if ("`geo'"=="occ_agg") | ("`geo'"=="occ1990") | ("`geo'"=="occ1990_agg")  {
drop if occ1990==999
drop if occ_agg==.
drop if occ1990_agg==.
}

nativity_selection_census

generate byte agecode=1*(age>=25 & age<=34) + 2*(age>=35 & age<=44) + 3*(age>=45 & age<=54) + 4*(age>=55 & age<=59)

generate edcode=1*(educd<=61) + 2*(educd==62) + 3*(educd>=65 & educd<=90) + 4*(educd>=100) if year==1990
replace edcode=1*(educd<60) + 2*(educd>=60 & educd<65) + 3*(educd>=65 & educd<=90) + 4*(educd>=100) if year==1980 // In the 1980 we cannot distinguish between high school grads and those who did 12 years, but did not graduate

if ("`education'"=="aggregate") {
replace edcode=2 if edcode>=2 // This allows for a comparison of most affected to leasts affected groups
}

if ("`education'"=="aggregate2") {
replace edcode=3 if edcode>=3 // This allows for a comparison of most affected to leasts affected groups
}

replace `geo' = int(`geo'/10) if year==1990 //migmet5 is 4 digit code, this makes it to 3 digit code.

collapse (rawsum) cuban recent other native total=perwt native_emp native_unemp native_inactive (count) nobs=native, by(`geo' year edcode `age')

if ("`geo'"=="migmet5") {
ren `geo' metarea
}

merge m:1 metarea using `tf_goodmsa'.dta, keep(3) 

egen code=group(metarea  edcode  `age')

tsset code year

generate native_lf=native_emp+native_unemp

generate nat1_census=total-cuban-recent
generate nat0_census=total

generate cub1_census=cuban/(total-cuban-recent)
//generate cub1_census=cuban/(total-cuban)
generate cub0_census=cuban/(total)

generate other1_census=recent/(total-cuban-recent)

keep edcode `age' metarea cub1 cub0 year other1

replace year=1 //Makes sure to assign it to post-shock period.


*** Labeling variables

label var cub1_census "Inflows of Cubans, Census"
label var cub0_census "L.Share of Cubans, Census"

save `saveas', replace

end




/***********************
** CALLS
***********************/

* Option 1: SECOND MOST PREFERRED OPTION
//global period_selection "(year>=1977 & year<=1979) | (year>=1981 & year<=1983)"  //This selection increases s.e. and attenuates p.e.
//global years 3

* Option 2: MOST PREFERRED OPTION 
global period_selection "(year>=1977 & year<=1979) | (year>=1981 & year<=1984)"  //This selection increases s.e. and attenuates p.e.
global years 4

/***********************
** CLEAN CPS DATA
***********************/

clean_cps


/***********************
** SUMMARY STATS AND GRAPHS OF DISTRIBUTION OF THE SHOCK
***********************/

sumstats_census using "$dropbox/source/Census_1990.dta", agemin(25) agemax(59) sex(1) geo(migmet5) 
sumstats_dependent using "$dropbox/data/march_sample.dta", agemin(25) agemax(59) sex(1) period($period_selection) num_years($years)

/***********************
** MAIN REGRESSIONS
***********************/

/***********************
** DIRECT EFFECT OF IMMIGRATION
***********************/

*GEOGRAHY

** Male population age>25 & age<59 

tempfile tf_census_metarea_data_1985 tf_census_metarea_data_1980

aggregate_census_data using "$dropbox/source/Census_1990.dta", agemin(25) agemax(59) sex(1) geo(migmet5) saveas(`tf_census_metarea_data_1985'.dta)  
aggregate_census_data using "$dropbox/source/Census_1980.dta", agemin(25) agemax(59) sex(1) geo(metarea) saveas(`tf_census_metarea_data_1980'.dta)  
aggregate_data using "$dropbox/data/march_sample.dta", agemin(25) agemax(59) sex(1) geo(metarea) period($period_selection) num_years($years) 
regressions, tablenum(geo_male) geo(metarea) census(yes) census_file1(`tf_census_metarea_data_1985'.dta) census_file2(`tf_census_metarea_data_1980'.dta) age(i.metarea) file_name(Mariel_estimation_data) 

aggregate_census_data using "$dropbox/source/Census_1990.dta", agemin(25) agemax(59) sex(1) geo(migmet5) saveas(`tf_census_metarea_data_1985'.dta)
aggregate_census_data using "$dropbox/source/Census_1980.dta", agemin(25) agemax(59) sex(1) geo(metarea) saveas(`tf_census_metarea_data_1980'.dta) 
aggregate_data using "$dropbox/data/march_sample.dta", agemin(25) agemax(59) sex(1) geo(metarea) period($period_selection) num_years($years) //data_set(morg) 
regressions_cross_effect, tablenum(geo_male_disagg) geo(metarea) census(yes) census_file1(`tf_census_metarea_data_1985'.dta) census_file2(`tf_census_metarea_data_1980'.dta) age(i.metarea)

** EXTRA CHECKS, NOT IN THE PAPER

/*

** own-effects, aggregate education

aggregate_census_data using "$sources/Census_data/source/Census_1990.dta", agemin(25) agemax(59) sex(1) geo(migmet5) saveas(`tf_census_metarea_data_1985'.dta) education(aggregate) //age(agecode) 
aggregate_census_data using "$sources/Census_data/source/Census_1980.dta", agemin(25) agemax(59) sex(1) geo(metarea) saveas(`tf_census_metarea_data_1980'.dta) education(aggregate) //age(agecode) 
aggregate_data using "$dropbox/data/march_sample.dta", agemin(25) agemax(59) sex(1) geo(metarea) period($period_selection) num_years($years) education(aggregate) //age(agecode) 
regressions_cross_effect, tablenum(geo_male) geo(metarea) census(yes) census_file1(`tf_census_metarea_data_1985'.dta) census_file2(`tf_census_metarea_data_1980'.dta) age(i.metarea) education(aggregate)

aggregate_census_data using "$sources/Census_data/source/Census_1990.dta", agemin(25) agemax(59) sex(1) geo(migmet5) saveas(`tf_census_metarea_data_1985'.dta) education(aggregate2) //age(agecode) 
aggregate_census_data using "$sources/Census_data/source/Census_1980.dta", agemin(25) agemax(59) sex(1) geo(metarea) saveas(`tf_census_metarea_data_1980'.dta) education(aggregate2) //age(agecode) 
aggregate_data using "$dropbox/data/march_sample.dta", agemin(25) agemax(59) sex(1) geo(metarea) period($period_selection) num_years($years) education(aggregate2) //age(agecode) 
regressions_cross_effect, tablenum(geo_male_3groups) geo(metarea) census(yes) census_file1(`tf_census_metarea_data_1985'.dta) census_file2(`tf_census_metarea_data_1980'.dta) age(i.metarea) education(aggregate2)

** own-effects, aggregate education

aggregate_census_data using "$sources/Census_data/data/RawDataCensus1990.dta", agemin(25) agemax(59) sex(1) geo(migmet5) saveas(`tf_census_metarea_data_1985'.dta) education(aggregate) //age(agecode) 
aggregate_census_data using "$sources/Census_data/data/RawDataCensus1980.dta", agemin(25) agemax(59) sex(1) geo(metarea) saveas(`tf_census_metarea_data_1980'.dta) education(aggregate) //age(agecode) 
aggregate_data using "$dropbox/data/march_sample.dta", agemin(25) agemax(59) sex(1) geo(metarea) period($period_selection) num_years($years) education(aggregate) //age(agecode) 
regressions, tablenum(geo_male) geo(metarea) census(yes) census_file1(`tf_census_metarea_data_1985'.dta) census_file2(`tf_census_metarea_data_1980'.dta) age(i.metarea) education(aggregate)


*OCCUPATIONS

//sumstats using "$dropbox/data/march_sample.dta", agemin(25) agemax(59) sex(1) geo(occ_agg) period($period_selection) num_years($years) //age(agecode) 

** Male population age>25 & age<59

aggregate_data using "$dropbox/data/march_sample.dta", agemin(25) agemax(59) sex(1) geo(occ_agg) period($period_selection) num_years($years) //age(agecode) 
regressions, tablenum(occ_male) geo(occ_agg) //age(i.agecode)



